*******************************************************************************
*
*         STUNES.S      by Kevin G. Osborn
*         ADAPTED FOR SPHINX --- A GAME OF SKILL AND CHANCE
*         Contains subroutines
*                 TUNER
*                 SCRAPALL
*                 SCRAPONE
*                 TUNIN
*******************************************************************************
********************************************************************************
* SIMPSONG VERSION 0.035
*
* THIS SIMPLE SOUND DRIVER HAS, IN SOME WAYS, FEWER FEATURES BUT USES LESS RAM
* AND ROM AND DOES NOT BACK UP SOUNDS FOR LATER (SOMETIMES MUCH LATER)
* CONTINUATION. IT FEATURES 256 NOTE TUNES, SINGLE DURATION PER TUNE, ENDLESS
* TUNES. IF A VALUE IN THE CONTROL OR VOLUME TABLES HAS THE HIGH BIT SET, THAT
* VOLUME OR CONTROL WILL REMAIN IN EFFECT TILL THE END OF THE TUNE.
* AN FF IN THE FREQUENCY TABLE WILL TERMINATE THE TUNE, AN FE WILL CAUSE IT TO
* RESTART.  AN FD WILL DECREMENT TUNREPT.  IF THIS IS NON-ZERO, THE TUNE
* CONTINUES.  IF IT IS ZERO, THE NEXT BYTE IN FREQ. TABLE IS S TUNE WHICH
* SHOULD BE CALLED.  TUNREPT IS SET IN TUNIN.
*
* AS A NEW WHIZZY FEATURE, TUNER ALSO SUPPORTS RESTS. IF BIT 6 IS SET (NOT BIT 7
* ALSO) IN A FREQUENCY TABLE ENTRY, IT SILENCES SOUND IN THAT CHANNEL FOR THE
* NUMBER OF FRAMES INDICATED IN THE REMAINING 5 BITS.
*
* NOTE ALSO THAT IN THIS VERSION A DURATION OF 1 INDICATES CHANGING SOUND EVERY
* FRAME. THIS IS A CHANGE OVER VERSION .03 WHERE 0 INDICATED ONCE PER FRAME
* SAMPLING.
* SUBROUTINES:
*     SCRAPALL -- KILL ALL TUNES. SHOULD BE CALLED AT POWERUP, CHANGING PLAYERS,
*                AND GAME OVER
*
*     SCRAPONE -- KILL A PARTICULAR TUNE. PUT THE NUMBER OF THE TUNE YA WANNA
*                 AXE IN THE ACCUMULATOR.
*
*     TUNIN   --  START THAT TUNE YOU PUT IN ACC.
*
* THE ABOVE ROUTINES PRESERVE THE X AND Y REGS
*
* TABLES NEEDED ARE:
* RAM:
*DCH0      DS      1                      ONE BYTE--DURATION CNTR CHAN. 0
*DCH1      DS      1                      ONE BYTE--DURATION CNTR CHAN. 1
*TUNNUM    DS      1                      ONE BYTE--TUNE NUM FOR CHAN. 0
*TUNNUM1   DS      1                      ONE BYTE--TUNE NUM FOR CHAN. 1
*TINDEX0   DS      1                      ONE BYTE--NOTE POINTER 0
*TINDEX1   DS      1                      ONE BYTE--NOTE POINTER 1
*CINDEX0   DS      1                      CONTROL INDEX
*CINDEX1   DS      1
*VINDEX0   DS      1                      VOLUME INDEX
*VINDEX1   DS      1
*TUNREPT0  DS      1                      TUNE REPEAT COUNTER
*TUNREPT1  DS      1
*MPTRL     EQU     KTEMP0                 ZERO PAGE TEMP(NOT GAMEPLAY)
*MPTRH     EQU     KTEMP1                 ZERO PAGE TEMP(NOT GAMEPLAY)
*TUNTEMP   EQU     TEMP0                  ANY GAMEPLAY TEMP
* ROM:
*   DURTABL       ONE DURATION IN FRAMES PER TUNE
*   TBASE         LOW ADDRESS OF THE START OF FREQ DATA BY TUNE NUMBER
*   TBASEH        DITTO FOR HIGH ADDRESS
*   VBASE         LOW ADDRESS OF THE START OF VOL DATA BY TUNE NUMBER
*   VBASEH        DITTO FOR HIGH ADDRESS
*   CBASE         LOW ADDRESS OF THE START OF CTRL DATA BY TUNE NUMBER
*   CBASEH        DITTO FOR HIGH ADDRESS
*   PRYOR         PRIORITY BY TUNE NUMBERS  --  ZERO THE LOWEST
*   VOLTABL       VOLUMES
*   FREQTABL      FREQUENCIES
*   CTLTABL       CONTROLS


          ZERODEF

          RSEG    CODE6

********************************************************************************
* SCRAPALL
*         KILL ALL TUNES. SHOULD BE CALLED AT POWERUP, CHANGING PLAYERS,
*                AND GAME OVER
*         USES A , DOESN'T USE X OR Y
          ;IF WE CAN USE X HERE, THEN WE CAN SAVE A BYTE
SCRAPALL
          LDA     #0
          STA     AUDV0                  ;CLEAR SOUND REGISTERS
          STA     AUDV1
          LDA     #$FF
          STA     TUNNUM                 ;FLAG NO TUNES, BOTH CHANNELS
          STA     TUNNUM1
          RTS

; IF YOU WANT, LOOP THIS UP

********************************************************************************
* SCRAPONE
*         KILL A PARTICULAR TUNE. PUT THE NUMBER OF THE TUNE YA WANNA
*                 AXE IN THE ACCUMULATOR.
          ;CAN WE USE X OR Y HERE??

SCRAPONE  CMP     TUNNUM                 ;ON CHAN 0?
          BNE     CKCH1
          LDA     #0
          STA     AUDV0                  ;CLEAR REGISTER
          LDA     #$FF
          STA     TUNNUM                 ;FLAG NO TUNE, CHANNEL 0
          RTS
CKCH1     SEC
          SBC     TUNNUM1                ;ON CHAN 1?
          BNE     REETS                  ;IF NON ZERO, RETURN
          STA     AUDV1                  ;CLEAR REGISTER
          LDA     #$FF
          STA     TUNNUM1                ;FLAG NO TUNE, CHAN 1
REETS     RTS

********************************************************************************
* TUNIN
*         START THAT TUNE YOU PUT IN ACC.
TUNIN     STA     TUNTEMP
          BIT     GAMEU
          BPL     REETS2
          TYA                            ;SAVE Y,X REGS ON STACK
          PHA
          TXA
          PHA
          LDY     #1
TROIKA    LDA     TUNNUM,Y               ;FIRST CHECK FOR AN EMPTY CHANNEL
          CMP     #$FF
          BEQ     DO
TRKNX     DEY
          BPL     TROIKA

          LDA     TUNNUM1                ;THIS IS DONE TO PREVENT GLITCHINESS
          AND     #$7F
          TAY
          LDA     TUNNUM
          AND     #$7F
          TAX
          LDA     PRYOR,Y
          LDY     #1
          CMP     PRYOR,X
          BCC     REPTUN1
          LDY     #0
REPTUN1
          LDA     TUNNUM,Y
          AND     #$7F
          TAX
          LDA     PRYOR,X
          LDX     TUNTEMP
          CMP     PRYOR,X
          BCS     ROOTS

DO        LDX     TUNTEMP
          CPX     #HISCOR0
          BCC     REGDO
          CPX     #LOSCOR1+1
          BCS     REGDO

          LDA     #4                     ;REPEAT HISCORE TUNES FOUR TIMES
          STA     TUNREPT0,Y             ;BEFORE GOING TO ENDING

REGDO
          TXA                            ;PLAY TUNE X ON CHANNEL Y
          ORA     #$80                   ;SET HIGH BIT
          STA     TUNNUM,Y

          LDA     #BACKGR0               ;PUNT BOTH CHANNELS OF BACKGROUND
          JSR     SCRAPONE
          LDA     #BACKGR1
          JSR     SCRAPONE

ROOTS     PLA                            ;RESTORE X,Y REGISTERS
          TAX
          PLA
          TAY
REETS2    RTS

********************************************************************************
*TUNER SHOULD BE CALLED ONCE PER FRAME, NO INPUTS, AND IT OPERATES WITH
*A TOTAL DISREGARD FOR REGISTER SANCTITY. EACH TUNE CAN BE 256 NOTES LONG
*IF YOUR TUNES ARE VERY SMALL, YOU COULD DO AWAY WITH ALL THE INDIRECT STUFF

TUNER
;PUT A CHECK FOR ATTRACT MODE HERE

          BIT     GAMEU
          BMI     NOREETS                ; RTS  WHEN IN ATTRACT MODE
          LDA     #0
          STA     AUDV0                  ;TURN OFF SOUND
          STA     AUDV1
          BEQ     REETS2

* PLAY CHANNELS 0 AND 1 *
NOREETS   LDX     #1

TUNLOP    LDY     TUNNUM,X
          INY
          BNE     NETN                   ;TUNNUM=FF DO NEXT CHANNEL
JNXTCH    JMP     NXTCH
NETN      DEY
          BPL     BOOGIE

* INITIALIZE A NEW TUNE (HIGH BIT ON Y IS SET) *
          TYA
          AND     #$7F
          STA     TUNNUM,X
          TAY
          LDA     #1
          STA     DCH0,X                 ;START (DCHANNEL(X)=1)
          LDA     #$FF                   ; INCREMENTS ON THE FIRST CALL
          STA     TINDEX0,X              ;AND INDEXES WILL BE ZEROED.
          STA     CINDEX0,X
          STA     VINDEX0,X
          LDA     #0
          STA     VRUN,X

BOOGIE    LDA     TBASE,Y
          STA     MPTRL
          LDA     TBASEH,Y
          STA     MPTRH                  ;MPTR = FREQUENCY BASE ADDRESS

          DEC     DCH0,X                 ;DEC DURATION
          BNE     JNXTCH

          LDA     DURTABL,Y              ;NEW DURATION
          STA     DCH0,X
          LDY     TINDEX0,X              ;FREQUENCY INDEX (OFF OF BASE)
          INC     CINDEX0,X
          INC     VINDEX0,X
          INY
          LDA     (MPTRL),Y              ;FETCH FREQUENCY

          CMP     #$FF                   ;IS IT OVER?
          BNE     CKENL
          STA     TUNNUM,X               ;END THIS FUNKY TUNE
          LDA     #0
          STA     AUDV0,X
          BEQ     JNXTCH                 ;JMP NEXT CHANNEL

SKIPTWO
          INY
          JMP     PSTFREQ                ;Y BETTER NOT BE ZERO HERE

CKENL     CMP     #$FE                   ;CODE FOR PLAYING TUNE AGAIN
          BEQ     FOOBEQ

CKNXTT    CMP     #$FD
          BNE     SKIP                   ;DO A NORMAL FREQUENCY!

* CODE $FD --> JUMP TO ANOTHER TUNE *
          INY                            ;DEFINATELY SKIP TO NEXT BYTE

          DEC     TUNREPT0,X             ;IF NOT DONE REPEATING, SKIP THIS AND
          BNE     SKIPTWO                ;NEXT BYTE IN FREQ TABLE.

          LDA     (MPTRL),Y              ;NEXT BYTE IS NEW TUNE
          STA     TUNNUM,X
          TAY
          LDA     TBASE,Y
          STA     MPTRL
          LDA     TBASEH,Y
          STA     MPTRH                  ;LOAD NEW BASE

* CODE $FE --> PLAY THE TUNE AGAIN *
FOOBEQ    LDY     #0
          TYA
          STA     CINDEX0,X              ;RESET CONTROL, VOLUME INDEXES
          STA     VINDEX0,X
          STA     VRUN,X
PSTFREQ   LDA     (MPTRL),Y

; STFREQ    BPL     SKIP                   ;IF BIT 7 CLR, DO A REST

* CHANGE THE DURATION *
; HUH       INY
  ;       LDA     (MPTRL),Y
   ;      STA     DCH0,X                 ;STORE DURATION
    ;     DEY
     ;    LDA     (MPTRL),Y
      ;   INY
       ;  JMP     STIT0                  ;STORE FREQUENCY

* CHECK FOR A REST *
SKIP      ASL     A
          BPL     STIT                   ;STORE FREQ IF BIT 6 CLEAR
          LSR     A
          AND     #$BF                   ;RESET BIT 6
          STA     DCH0,X                 ;USE REMAINING 5 BITS FOR
          TYA                            ;A DURATION OF SILENCE
          STA     TINDEX0,X
          DEC     VINDEX0,X
          DEC     CINDEX0,X              ;HOLD CONTROL AND VOLUME INDEXES

          LDA     #0                     ;SILENCE
          STA     AUDV0,X
          BEQ     NXTCH                  ;JMP NEXT CHANNEL

* STORE OUT THE FREQUENCY *
STIT      LSR     A
STIT0     STA     AUDF0,X                ;STORE AUDIO FREQUENCY
          TYA
          STA     TINDEX0,X              ;TINDEX = Y

* LOOK UP VOLUME *
          DEC     VRUN,X
          BPL     CTRLOAD

          LDY     TUNNUM,X
          LDA     VBASE,Y
          STA     MPTRL
          LDA     VBASEH,Y
          STA     MPTRH                  ;MPTR = VOLUME BASE
          LDY     VINDEX0,X              ;Y = VINDEX
          LDA     (MPTRL),Y
          TAY
          AND     #$0F
          STA     AUDV0,X                ;STORE AUDIO VOLUME
          TYA
          BMI     CTRLOAD                ;HIGH BIT SET

          LSR     A
          LSR     A
          LSR     A
          LSR     A
          STA     VRUN,X
          INC     VINDEX0,X

* LOOK UP CONTROL *
CTRLOAD
          DEC     VINDEX0,X
          LDY     TUNNUM,X
          LDA     CBASE,Y
          STA     MPTRL
          LDA     CBASEH,Y
          STA     MPTRH
          LDY     CINDEX0,X              ;Y = CINDEX
          LDA     (MPTRL),Y
          BPL     STCTRL
          DEY                            ;REPEAT FOREVER
          AND     #$7F
STCTRL    STA     AUDC0,X                ;STORE AUDIO CONTROL
          TYA
          STA     CINDEX0,X              ;CINDEX = Y

NXTCH     DEX                            ;X = 0 (NEXT CHANNEL)
          BMI     ROTS
          JMP     TUNLOP                 ;DO CHANNEL 0
ROTS      RTS

RUNBACK
;PUT A CHECK FOR ATTRACT MODE HERE

          BIT     GAMEU
          BMI     NORTSBK                ; RTS  WHEN IN ATTRACT MODE
          LDA     #0
          STA     AUDV0                  ;TURN OFF SOUND
          STA     AUDV1
          RTS

* PLAY CHANNELS 0 AND 1 *
NORTSBK   LDX     #1

BAKLOP    LDY     BACKNUM,X
          LDA     TBASE,Y
          STA     MPTRL
          LDA     TBASEH,Y
          STA     MPTRH                  ;MPTR = FREQUENCY BASE ADDRESS

          DEC     DBK0,X                 ;DEC DURATION
          BNE     JNEXBK

          LDA     DURTABL,Y              ;NEW DURATION
          STA     DBK0,X
          LDY     TBINDX0,X              ;FREQUENCY INDEX (OFF OF BASE)
          INC     CBINDX0,X
          INC     VBINDX0,X
          INY
          LDA     (MPTRL),Y              ;FETCH FREQUENCY

          CMP     #$FE                   ;CODE FOR PLAYING TUNE AGAIN
          BNE     STITBK

* CODE $FE --> PLAY THE TUNE AGAIN *
REPEATER  LDY     #0
          TYA
          STA     CBINDX0,X              ;RESET CONTROL, VOLUME INDEXES
          STA     VBINDX0,X
          STA     VBRUN,X
PLOKRST   LDA     (MPTRL),Y

; LOOKRST   BPL     SKIPBK                 ;IF BIT 7 CLR, DO A REST

* CHANGE THE DURATION *
; HUH1      INY
  ;       LDA     (MPTRL),Y
   ;      STA     DBK0,X                 ;STORE DURATION
    ;     DEY
     ;    LDA     (MPTRL),Y
      ;   INY
       ;  BNE     STITBK                 ;STORE FREQUENCY

* CHECK FOR A REST *
SKIPBK    ASL     A
          BPL     STITBK                 ;STORE FREQ IF BIT 6 CLEAR
          LSR     A
          AND     #$BF                   ;RESET BIT 6
          STA     DBK0,X                 ;USE REMAINING 5 BITS FOR
          TYA                            ;A DURATION OF SILENCE
          STA     TBINDX0,X
          DEC     VBINDX0,X
          DEC     CBINDX0,X              ;HOLD CONTROL AND VOLUME INDEXES
JNEXBK    JMP     NEXBK

* STORE OUT THE FREQUENCY *
STITBK
          TYA
          STA     TBINDX0,X              ;TINDEX = Y

* LOOK UP VOLUME *
          DEC     VBRUN,X
          BPL     CBLOAD

          LDY     BACKNUM,X
          LDA     VBASE,Y
          STA     MPTRL
          LDA     VBASEH,Y
          STA     MPTRH                  ;MPTR = VOLUME BASE
          LDY     VBINDX0,X              ;Y = VINDEX
          LDA     (MPTRL),Y
          BMI     CBLOAD                 ;HIGH BIT SET

          LSR     A
          LSR     A
          LSR     A
          LSR     A
          STA     VBRUN,X
          INC     VBINDX0,X

* LOOK UP CONTROL *
CBLOAD
          DEC     VBINDX0,X
          LDY     BACKNUM,X
          LDA     CBASE,Y
          STA     MPTRL
          LDA     CBASEH,Y
          STA     MPTRH
          LDY     CBINDX0,X              ;Y = CINDEX
          LDA     (MPTRL),Y
          BPL     STCBX
          DEY                            ;REPEAT FOREVER
STCBX
          TYA
          STA     CBINDX0,X              ;CINDEX = Y

NEXBK     DEX                            ;X = 0 (NEXT CHANNEL)
          BMI     ROTSBK
          JMP     BAKLOP                 ;DO CHANNEL 0
ROTSBK    RTS

BACKON
          BIT     GAMEU
          BPL     NOBAKON

          LDA     DEATH
          BNE     NOBAKON                ;NOT WHEN BIRD IS DYING

          LDA     TUNNUM
          AND     TUNNUM+1
          CMP     #$FF
          BNE     NOBAKON

          LDX     #1
BAKONLP
          LDA     BACKNUM,X
          STA     TUNNUM,X

          LDA     DBK0,X
          STA     DCH0,X

          LDA     TBINDX0,X
          STA     TINDEX0,X

          LDA     CBINDX0,X
          STA     CINDEX0,X

          LDA     VBINDX0,X
          STA     VINDEX0,X

          LDA     VBRUN,X
          STA     VRUN,X

          DEX
          BPL     BAKONLP

NOBAKON   RTS


BRDSHOT   EQU     0                      ;TUNE NUMBERS
RICCHET   EQU     1
UWERUN    EQU     2
ALADIN0   EQU     3
ALADIN1   EQU     4
UWEEXP    EQU     5
SCBEXPL   EQU     6
GLDEXPL   EQU     7
SWIM      EQU     8
ENDGAM0   EQU     9
ENDGAM1   EQU     10
MINISHOT  EQU     11
VHDEATH   EQU     12
CUCKOO1   EQU     13
CUCKOO2   EQU     14
NHIERO1   EQU     15
NHIERO2   EQU     16
NHIERO3   EQU     17
HMISS3    EQU     18
SPTUNE    EQU     19                     ;SPAWN
RUNNING   EQU     20
JWTUNE    EQU     21                     ;JEWEL
SFINKS    EQU     22
XLPOWER   EQU     23
POWRUSE   EQU     24
SPHXBM0   EQU     25
SPHXBM1   EQU     26
MINIBM    EQU     27
HISCOR0   EQU     28
HISCOR1   EQU     29
LOSCOR0   EQU     30
LOSCOR1   EQU     31
HISEND0   EQU     32
HISEND1   EQU     33
LOSEND0   EQU     34
LOSEND1   EQU     35
BACKGR0   EQU     36
BACKGR1   EQU     37
FLASHT0   EQU     38
FLASHT1   EQU     39

BACKNUM   DB      BACKGR0,BACKGR1


********************************************************************************
*         pointer tables.
TBASE     DB      L(BRDSHOTF),L(RICCHETF),L(UWERUNF),L(ALADIN0F),L(ALADIN1F)
          DB      L(UWEEXPF),L(SCBEXPLF),L(GLDEXPLF)
          DB      L(SWIMF),L(ENDGAM0F),L(ENDGAM1F)
          DB      L(MINISHTF)
          DB      L(VHDEATHF),L(CUCKOO1F),L(CUCKOO2F)
          DB      L(NHIERO1F),L(NHIERO2F),L(NHIERO3F),L(HMISS3F)
          DB      L(SPAWNF),L(RUNNINGF)
          DB      L(JEWELF),L(SFINKSF),L(XLPOWERF)
          DB      L(POWRUSEF),L(SPHXBM0F),L(SPHXBM1F),L(MINIBMF)
          DB      L(HISCOR0F),L(HISCOR1F),L(LOSCOR0F),L(LOSCOR1F)
          DB      L(HISEND0F),L(HISEND1F),L(LOSEND0F),L(LOSEND1F)
          DB      L(BACKGR0F),L(BACKGR1F),L(FLASHT0F),L(FLASHT1F)

TBASEH    DB      H(BRDSHOTF),H(RICCHETF),H(UWERUNF),H(ALADIN0F),H(ALADIN1F)
          DB      H(UWEEXPF),H(SCBEXPLF),H(GLDEXPLF)
          DB      H(SWIMF),H(ENDGAM0F),H(ENDGAM1F)
          DB      H(MINISHTF)
          DB      H(VHDEATHF),H(CUCKOO1F),H(CUCKOO2F)
          DB      H(NHIERO1F),H(NHIERO2F),H(NHIERO3F),H(HMISS3F)
          DB      H(SPAWNF),H(RUNNINGF)
          DB      H(JEWELF),H(SFINKSF),H(XLPOWERF)
          DB      H(POWRUSEF),H(SPHXBM0F),H(SPHXBM1F),H(MINIBMF)
          DB      H(HISCOR0F),H(HISCOR1F),H(LOSCOR0F),H(LOSCOR1F)
          DB      H(HISEND0F),H(HISEND1F),H(LOSEND0F),H(LOSEND1F)
          DB      H(BACKGR0F),H(BACKGR1F),H(FLASHT0F),H(FLASHT1F)

VBASE     DB      L(BRDSHOTV),L(RICCHETV),L(UWERUNV),L(ALADIN0V),L(ALADIN1V)
          DB      L(UWEEXPV),L(SCBEXPLV),L(GLDEXPLV)
          DB      L(SWIMV),L(ENDGAM0V),L(ENDGAM1V)
          DB      L(MINISHTV)
          DB      L(VHDEATHV),L(CUCKOO1V),L(CUCKOO2V)
          DB      L(NHIERO1V),L(NHIERO2V),L(NHIERO3V),L(HMISS3V)
          DB      L(SPAWNV),L(RUNNINGV)
          DB      L(JEWELV),L(SFINKSV),L(XLPOWERV)
          DB      L(POWRUSEV),L(SPHXBM0V),L(SPHXBM1V),L(MINIBMV)
          DB      L(HISCOR0V),L(HISCOR1V),L(LOSCOR0V),L(LOSCOR1V)
          DB      L(HISEND0V),L(HISEND1V),L(LOSEND0V),L(LOSEND1V)
          DB      L(BACKGR0V),L(BACKGR1V),L(FLASHT0V),L(FLASHT1V)

VBASEH    DB      H(BRDSHOTV),H(RICCHETV),H(UWERUNV),H(ALADIN0V),H(ALADIN1V)
          DB      H(UWEEXPV),H(SCBEXPLV),H(GLDEXPLV)
          DB      H(SWIMV),H(ENDGAM0V),H(ENDGAM1V)
          DB      H(MINISHTV)
          DB      H(VHDEATHV),H(CUCKOO1V),H(CUCKOO2V)
          DB      H(NHIERO1V),H(NHIERO2V),H(NHIERO3V),H(HMISS3V)
          DB      H(SPAWNV),H(RUNNINGV)
          DB      H(JEWELV),H(SFINKSV),H(XLPOWERV)
          DB      H(POWRUSEV),H(SPHXBM0V),H(SPHXBM1V),H(MINIBMV)
          DB      H(HISCOR0V),H(HISCOR1V),H(LOSCOR0V),H(LOSCOR1V)
          DB      H(HISEND0V),H(HISEND1V),H(LOSEND0V),H(LOSEND1V)
          DB      H(BACKGR0V),H(BACKGR1V),H(FLASHT0V),H(FLASHT1V)

CBASE     DB      L(BRDSHOTC),L(RICCHETC),L(UWERUNC),L(ALADIN0C),L(ALADIN1C)
          DB      L(UWEEXPC),L(SCBEXPLC),L(GLDEXPLC)
          DB      L(SWIMC),L(ENDGAM0C),L(ENDGAM1C)
          DB      L(MINISHTC)
          DB      L(VHDEATHC),L(CUCKOO1C),L(CUCKOO2C)
          DB      L(NHIERO1C),L(NHIERO2C),L(NHIERO3C),L(HMISS3C)
          DB      L(SPAWNC),L(RUNNINGC)
          DB      L(JEWELC),L(SFINKSC),L(XLPOWERC)
          DB      L(POWRUSEC),L(SPHXBM0C),L(SPHXBM1C),L(MINIBMC)
          DB      L(HISCOR0C),L(HISCOR1C),L(LOSCOR0C),L(LOSCOR1C)
          DB      L(HISEND0C),L(HISEND1C),L(LOSEND0C),L(LOSEND1C)
          DB      L(BACKGR0C),L(BACKGR1C),L(FLASHT0C),L(FLASHT1C)

CBASEH    DB      H(BRDSHOTC),H(RICCHETC),H(UWERUNC),H(ALADIN0C),H(ALADIN1C)
          DB      H(UWEEXPC),H(SCBEXPLC),H(GLDEXPLC)
          DB      H(SWIMC),H(ENDGAM0C),H(ENDGAM1C)
          DB      H(MINISHTC)
          DB      H(VHDEATHC),H(CUCKOO1C),H(CUCKOO2C)
          DB      H(NHIERO1C),H(NHIERO2C),H(NHIERO3C),H(HMISS3C)
          DB      H(SPAWNC),H(RUNNINGC)
          DB      H(JEWELC),H(SFINKSC),H(XLPOWERC)
          DB      H(POWRUSEC),H(SPHXBM0C),H(SPHXBM1C),H(MINIBMC)
          DB      H(HISCOR0C),H(HISCOR1C),H(LOSCOR0C),H(LOSCOR1C)
          DB      H(HISEND0C),H(HISEND1C),H(LOSEND0C),H(LOSEND1C)
          DB      H(BACKGR0C),H(BACKGR1C),H(FLASHT0C),H(FLASHT1C)

********************************************************************************
DURTABL   DB      $01                    ;BRDSHOT
          DB      $01                    ;RICCHET
          DB      $02                    ;UWERUN
          DB      $04                    ;ALADIN0
          DB      $04                    ;ALADIN1
          DB      $01                    ;UWEEXP
          DB      $01                    ;SCBEXPL
          DB      $01                    ;GLDEXPL
          DB      $03                    ;SWIM
          DB      $04                    ;ENDGAM0
          DB      $04                    ;ENDGAM1
          DB      $02                    ;MINISHOT
          DB      $02                    ;VHDEATH
          DB      $01                    ;CUCKOO1
          DB      $01                    ;CUCKOO2
          DB      $05                    ;NHIERO1
          DB      $05                    ;NHIERO2
          DB      $05                    ;NHIERO3
          DB      $02                    ;HMISS3
          DB      $02                    ;SPAWN
          DB      $03                    ;RUNNING
          DB      $02                    ;JEWEL
          DB      $02                    ;SFINKS
          DB      $03                    ;XLPOWER
          DB      $04                    ;POWRUSE
          DB      $02                    ;SPHXBM0
          DB      $02                    ;SPHXBM1
          DB      $03                    ;MINIBM
          DB      $08                    ;HISCOR0
          DB      $08                    ;HISCOR1
          DB      $08                    ;LOSCOR0
          DB      $08                    ;LOSCOR1
          DB      $08                    ;HISEND0
          DB      $08                    ;HISEND1
          DB      $08                    ;LOSEND0
          DB      $08                    ;LOSEND1
          DB      $02                    ;BACKGR0
          DB      $02                    ;BACKGR1
          DB      $06                    ;FLASHT0
          DB      $06                    ;FLASHT1

PRYOR     DB      $01                    ;BRDSHOT        OR THESE EVEN??
          DB      $02                    ;RICCHET
          DB      $02                    ;UWERUN
          DB      $05                    ;ALADIN0
          DB      $05                    ;ALADIN1
          DB      $03                    ;UWEEXP
          DB      $03                    ;SCBEXPL
          DB      $03                    ;GLDEXPL
          DB      $03                    ;SWIM
          DB      $09                    ;ENDGAM0
          DB      $09                    ;ENDGAM1
          DB      $04                    ;ANY MINISPHINX OR SPHINX SHOT
          DB      $06                    ;VHDEATH
          DB      $07                    ;CUCKOO1
          DB      $07                    ;CUCKOO2
          DB      $04                    ;NHIERO1
          DB      $04                    ;NHIERO2
          DB      $04                    ;NHIERO3
          DB      $04                    ;HMISS3
          DB      $03                    ;SPAWN
          DB      $02                    ;RUNNING
          DB      $04                    ;JEWEL
          DB      $03                    ;SFINKS
          DB      $04                    ;XLPOWER
          DB      $04                    ;POWRUSE
          DB      $05                    ;SPHXBM0
          DB      $05                    ;SPHXBM1
          DB      $04                    ;MINIBM
          DB      $0A                    ;HISCOR0
          DB      $0B                    ;HISCOR1
          DB      $0A                    ;LOSCOR0
          DB      $0B                    ;LOSCOR1
          DB      $0C                    ;HISEND0
          DB      $0D                    ;HISEND1
          DB      $0C                    ;LOSEND0
          DB      $0D                    ;LOSEND1
          DB      $00                    ;BACKGR0
          DB      $00                    ;BACKGR1
          DB      $08                    ;FLASHT0
          DB      $08                    ;FLASHT1

********************************************************************************
* FREQTABL
RICCHETF  DB      $44,$07,$07,$03,$06,$03,$06,$03,$06,$FF

BRDSHOTF  DB      $00,$01,$02,$03,$04,$05,$07,$09,$0B,$0D,$0F,$12,$14,$16
          DB      $18,$1C,$1B,$1A,$1C,$1B,$1A,$1C,$FF

ALADIN0F  DB      $1F,$1F,$48,$14,$44,$14,$44
          DB      $15,$15,$48,$14,$14,$48

          DB      $14,$14,$48,$13,$13,$48
          DB      $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D

          DB      $1F,$1F,$48,$14,$14,$15,$15
          DB      $14,$14,$15,$15,$14,$14,$15,$15

          DB      $14,$14,$48,$13,$13,$48
          DB      $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D

          DB      $1F,$1F,$48,$14,$44,$14,$44
          DB      $15,$15,$48,$14,$14,$48

          DB      $14,$14,$48,$13,$13,$48
          DB      $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D

          DB      $1F,$1F,$48,$14,$14,$15,$15
          DB      $14,$14,$15,$15,$14,$14,$15,$15

          DB      $14,$14,$48,$13,$13,$48
          DB      $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D

          DB      $1F,$1F,$48,$14,$44,$14,$44
          DB      $15,$15,$48,$14,$14,$48

          DB      $14,$14,$48,$13,$13,$48
          DB      $1D,$1D,$1D,$1D,$1D,$1D,$1D,$1D

          DB      $1F,$1F,$48,$14,$14,$15,$15
          DB      $14,$14,$15,$15,$14,$14,$15,$15

          DB      $1F,$1F,$1F,$1F,$1F,$1F,$1F,$1F
          DB      $FF

ALADIN1F  DB      $5F                    ;31
          DB      $5F                    ;62

          DB      $5F                    ;93
          DB      $5F                    ;124

          DB      $5F                    ;155
          DB      $5F                    ;186

          DB      $5F                    ;217
          DB      $5F,$48                ;248+8=256 FRAMES OF SILENCE

          DB      $13,$13,$12,$12,$0F,$0F,$0E,$0E
          DB      $0C,$0C,$48,$0F,$0F,$0E,$0E

          DB      $0C,$0C,$48,$0F,$0F,$0E,$0E
          DB      $0C,$0C,$0B,$0B,$0C,$0C,$0E,$0E

          DB      $0F,$0F,$48,$13,$13,$14,$14
          DB      $13,$13,$12,$12,$0F,$0F,$0E,$0E

          DB      $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F
          DB      $0F,$0F,$0F,$0F,$12,$12,$12,$12

          DB      $13,$13,$48,$13,$13,$14,$14
          DB      $18,$18,$18,$18,$14,$14,$14,$14

          DB      $13,$13,$14,$14,$13,$13,$12,$12
          DB      $0F,$0F,$0F,$0F,$0F,$0F,$0E,$0E

          DB      $0F,$0F,$48,$0C,$0C,$0E,$0E
          DB      $0F,$0F,$12,$12,$13,$13,$16,$16

          DB      $13,$13,$13,$13,$13,$13,$13,$13
          DB      $FF


UWEEXPF   DB      $16,$15,$14,$13,$12,$11,$41,$0F
          DB      $00,$0C,$01,$00,$0C,$00,$FF

GLDEXPLF  DB      $17,$17,$06,$06,$05,$04,$04,$04,$FF


ENDGAM0F  DB      $1F,$1F,$48,$14,$44,$14,$44,$15,$15,$48,$14,$14
          DB      $48,$14,$14,$48,$13,$13,$48,$1D,$1D,$1D,$1D
          DB      $1D,$1D,$1D,$1D,$1F,$1F,$1F,$1F,$1F,$1F,$1F,$1F,$FF

ENDGAM1F  DB      $13,$13,$12,$12,$0F,$0F,$0E,$0E,$0C,$0C,$48,$0F,$0F
          DB      $0E,$0E,$0C,$0C,$48,$0F,$0F,$0E,$0E,$0C,$0C,$0B,$0B
          DB      $0C,$0C,$0E,$0E,$09,$09,$09,$09,$09,$09,$09,$09,$FF

MINISHTF  DB      $03,$00,$07,$07,$05,$1F,$1F,$1F,$FF


VHDEATHF  DB      $19,$1A,$1B,$1C,$1D,$1E,$1F,$1A
          DB      $04,$05,$06
          DB      $07,$08,$09,$0A,$0B,$0C,$0D,$0E
          DB      $0F,$10,$11,$12,$13,$14,$15,$16
          DB      $17,$18,$19,$1A,$1B,$1C,$1D,$1E,$FF

CUCKOO1F  DB      $1E,$1D,$1F,$1A,$1E,$1C,$1F,$1A
          DB      $0C,$0C,$0C,$06,$05,$06,$0F,$0F
          DB      $0F,$0F,$0F,$0F,$03,$06,$04,$03
          DB      $06,$04,$0C,$0C,$0C,$03,$05,$04
          DB      $0F,$0F,$0F,$0F,$0F,$0F,$03,$04
          DB      $06,$04,$06,$04,$0C,$0C,$0C,$03
          DB      $06,$05,$0F,$0F,$0F,$0F,$0F,$0F,$FF

CUCKOO2F  DB      $00,$00,$00,$00,$00,$00,$00,$00
          DB      $03,$04,$05,$03,$04,$05,$03,$04
          DB      $05,$03,$04,$05,$03,$04,$05,$03
          DB      $04,$05,$03,$04,$05,$03,$04,$05
          DB      $03,$04,$05,$03,$04,$05,$03,$04
          DB      $05,$03,$04,$05,$03,$04,$05,$03
          DB      $04,$05,$03,$04,$05,$03,$04,$05,$FF

NHIERO1F  DB      $17,$16,$12,$11,$0F,$FF

NHIERO2F  DB      $45,$12,$11,$0F,$45,$12,$FF

NHIERO3F  DB      $11,$0F,$0E,$0F,$45,$0B,$0B,$0B,$FF

HMISS3F   DB      $45,$13,$15,$17,$18,$19,$1A,$1C,$15
          DB      $1F,$1D,$1F,$1D,$1F,$1D,$1F,$1D,$FF

SPAWNF    DB      $17,$17,$18,$18,$19,$19,$FF

RUNNINGF  DB      $1F,$1F,$1F,$49,$14,$12,$10,$0F,$FE     ;REPEATS

JEWELF    DB      $8,$7,$6,$5,$4,$3,$4,$4
          DB      $4,$4,$4,$4,$4,$4,$4,$4
          DB      $4,$4,$4,$4,$4,$4,$4,$4,$4,$4,$FF

SFINKSF   DB      $5,$4,$3,$2,$1,$8,$7,$6
          DB      $5,$4,$3,$3,$4,$3,$2,$FE      ;REPEATS

XLPOWERF  DB      $13,$43,$11,$43,$E,$43,$9,$9,$9,$9,$FF

UWERUNF   DB      9,$42,8,$42,4,$42,8,$42
          DB      7,$42,4,$42,6,$42,5,$42,6,$FF
SWIMF     DB      $8,$F,$8,$F,$8,$F,$8,$F
          DB      $8,$F,$8,$F,$8,$F,$8,$F,$FE        ;REPEATS
SCBEXPLF  DB      $06,$07,$0C,$10,$12,$15,$15,$00
          DB      $14,$18,$14,$12,$0E,$08,$07,$00,$FF

SPHXBM0F  DB      $08,$08,$03,$03,$04,$04,$06,$06
          DB      $08,$08,$03,$03,$04,$04,$06,$06
          DB      $08,$08,$03,$03,$04,$04,$06,$06
          DB      $08,$08,$03,$03,$04,$04,$06,$06,$FF

SPHXBM1F  DB      $0A,$0A,$0A,$0A,$0B,$0B,$0C,$0C
          DB      $0D,$0D,$0A,$0E,$0F,$0F,$10,$10
          DB      $11,$11,$12,$12,$13,$0C,$14,$14
          DB      $15,$0A,$16,$16,$17,$09,$18,$18,$FF

MINIBMF   DB      $12,$16,$17,$18,$19,$1A,$1B,$1C,$1D,$1E,$1F,$FF

POWRUSEF  DB      $07,$0B,$08,$0B,$07,$0B,$08,$0B,$07,$0B,$FF

HISCOR0F  DB      $0B,$09,$13,$06,$08,$0B,$0D,$11
          DB      $0E,$0D,$0E,$0B,$09,$0D,$08,$11
          DB      $0B,$06,$13,$05,$04,$13,$08,$09
          DB      $0B,$13,$10,$FD,HISEND0,$0E,$0D,$10,$11,$11,$FE     ;REPEATS

HISEND0F  DB      $0D,$11,$11,$11,$11,$FF

HISCOR1F  DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $12,$12,$12,$12,$12,$12,$12,$12
          DB      $FD,HISEND1,$12,$12,$12,$12,$0F,$0F,$0F,$0F,$FE     ;REPEA

HISEND1F  DB      $0F,$0F,$0F,$0F,$0D,$0D,$0D,$0D,$FF

LOSCOR0F  DB      $0B,$09,$06,$09,$08,$0B,$0D,$10
          DB      $11,$0E,$0D,$0E,$09,$0D,$08,$11
          DB      $0D,$0B,$09,$06,$13,$06,$08,$09
          DB      $0B,$13,$10,$FD,LOSEND0,$0E,$0D,$10,$11,$11,$FE     ;REPEATS

LOSEND0F  DB      $0D,$11,$11,$11,$11,$FF

LOSCOR1F  DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $12,$12,$12,$12,$12,$12,$12,$12
          DB      $FD,LOSEND1,$12,$12,$12,$12,$0F,$0F,$0F,$0F,$FE     ;REPEATS

LOSEND1F  DB      $0F,$0F,$0F,$0F,$0D,$0D,$0D,$0D,$FF

BACKGR1F
BACKGR0F  DB      $B,$B,$B,$B,$B,$B,$B,$B
          DB      $B,$B,$B,$B,$B,$B,$B,$B
          DB      $C,$C,$C,$C,$C,$C,$C,$C
          DB      $C,$C,$C,$C,$C,$C,$C,$C,$FE

FLASHT0F  DB      $0D,$0E,$10,$11,$0D,$0E,$12,$13
          DB      $0D,$0E,$10,$11,$0D,$0E,$12,$13,$FF

FLASHT1F  DB      $09,$08,$06,$13,$09,$08,$13,$05
          DB      $09,$08,$06,$13,$08,$08,$13,$05,$FF

********************************************************************************
* VOLTABL

RICCHETV  DB      $1F,$08,$07,$06,$05,$04,$02

BRDSHOTV  DB      $09,$18,$17,$16,$25,$24,$23,$22,$21


ALADIN0V  DB      $14,$04,$04
          DB      $14,$14

          DB      $14,$14
          DB      $75

          DB      $14,$34
          DB      $75

          DB      $14,$14
          DB      $75

          DB      $14,$04,$04
          DB      $14,$14

          DB      $14,$14
          DB      $75

          DB      $14,$34
          DB      $75

          DB      $14,$14
          DB      $75

          DB      $14,$04,$04
          DB      $14,$14

          DB      $14,$14
          DB      $75

          DB      $14,$34
          DB      $56

          DB      $32,$13,$12,$11

ALADIN1V
          DB      $15,$16,$17,$18
          DB      $19,$17,$18

          DB      $19,$17,$18
          DB      $19,$1A,$19,$18

          DB      $17,$17,$16
          DB      $17,$18,$19,$1A

          DB      $B9,$3A

          DB      $1A,$19,$18
          DB      $37,$38

          DB      $19,$18,$19,$1A
          DB      $3B,$3C

          DB      $1C,$1D,$1C
          DB      $1B,$1A,$19,$18

          DB      $39,$08,$07,$06,$05


UWEEXPV   DB      $04,$05,$06,$07,$08,$09,$0F
          DB      $0E,$0C,$09,$08,$06,$04

GLDEXPLV  DB      $18,$07,$06,$05,$04,$03,$02


ENDGAM0V  DB      $14,$04,$04,$14,$14
          DB      $14,$14,$75,$74

ENDGAM1V  DB      $15,$16,$17,$18,$19,$17,$18
          DB      $19,$17,$18,$19,$1A,$19
          DB      $18,$17,$06,$05,$04,$03,$02,$01

MINISHTV  DB      $0F,$07,$08,$06,$04,$03,$02,$01


VHDEATHV  DB      $18,$17,$16,$15
          DB      $E8
          DB      $37
          DB      $36,$35

CUCKOO1V  DB      $08,$07,$06,$05,$04,$05,$06,$07
          DB      $F5,$F5,$F5

CUCKOO2V  DB      $73,$F3,$F3,$F3

NHIERO1V  DB      $88

NHIERO2V  DB      $28,$8

NHIERO3V  DB      $38,$28

HMISS3V   DB      $1A,$1B,$1C,$1D
          DB      $1E,$1D,$1C,$1B

SPAWNV    DB      $8A
RUNNINGV  DB      $23,$33

JEWELV    DB      $3,$14,$15,$6,$19
          DB      $7,$8,$9,$A,$19,$18
          DB      $17,$16,$15,$4,$3,$2,$1
SFINKSV   DB      $47,$8,$19
          DB      $1A,$B,$1E,$C,$D
XLPOWERV  DB      $A,$A,$A,$1A,$9,$8

UWERUNV   DB      3,6,5,4
          DB      3,3,3,3,6
SWIMV     DB      2,3,4,5,4,3,$22
          DB      3,4,5,4,3,$22
SCBEXPLV  DB      $15,$16,$17,$18
          DB      $19,$18,$17,$16

SPHXBM0V  DB      $0D,$0E,$2F,$0E,$0D,$0C
          DB      $0B,$0A,$09,$08,$07,$06,$05,$04
          DB      $1A,$19,$18,$17
          DB      $16,$15,$14,$13

SPHXBM1V  DB      $7F
          DB      $7E
          DB      $7D
          DB      $1C,$19,$17,$15

MINIBMV   DB      $1F,$0D,$0C,$0B,$0A,$09,$08,$07,$06,$05

POWRUSEV  DB      $08,$07,$06,$05,$04,$03,$02,$02,$01,$01

LOSCOR0V
LOSEND0V
HISCOR0V
HISEND0V  DB      $88

HISCOR1V
HISEND1V  DB      $18,$17,$16,$15
          DB      $14,$13,$12,$11
          DB      $08,$17,$06,$15,$04,$03
          DB      $08,$07,$06,$05,$08,$07,$06,$05

LOSCOR1V  DB      $08,$05,$02,$90,$F0,$08,$05,$02,$00
LOSEND1V  DB      $08,$05,$03,$02

BACKGR1V
BACKGR0V  DB      6,6,4,2,1,$61,$31
          DB      6,6,4,2,1,$61,$31

FLASHT0V
FLASHT1V  DB      $78,8,7,6,5,4,3,2,1

********************************************************************************
* CTLTABL


MINISHTC  DB      $83

RICCHETC  DB      $08,$08,$8F

ALADIN0C
HMISS3C
ENDGAM0C  DB      $81

HISEND0C
HISCOR0C
          DB      $0D,$0D,$04,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$04,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
BACKGR0C
BACKGR1C
LOSCOR1C
LOSEND1C
HISEND1C
HISCOR1C
          DB      $8A

LOSEND0C
LOSCOR0C  DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$0D,$0D,$0D,$0D
          DB      $0D,$0D,$0D,$0D,$04,$8D

FLASHT0C
POWRUSEC
ALADIN1C
ENDGAM1C
RUNNINGC  DB      $8D

BRDSHOTC
UWEEXPC
UWERUNC
SWIMC
MINIBMC
GLDEXPLC  DB      $88

JEWELC    DB      $08,$08,$08,$08,$08,$08,$84
XLPOWERC
CUCKOO2C
NHIERO1C
NHIERO2C
NHIERO3C  DB      $84


VHDEATHC  DB      $03,$07,$0F,$08,$08,$08,$08,$08
          DB      $84

CUCKOO1C  DB      $08,$08,$08,$08,$08,$08,$08,$08
          DB      $84



SPAWNC    DB      $D,$1,$D,$1,$D,$1


SFINKSC   DB      $8F

SCBEXPLC  DB      $D,$D,7,7,4,4,$F,$F
          DB      $84

SPHXBM0C  DB      $08,$03,$08,$03,$08,$03,$08,$08
          DB      $08,$03,$08,$03,$08,$03,$08,$08
          DB      $08,$03,$08,$03,$08,$03,$08,$08
          DB      $08,$03,$08,$03,$08,$03,$08,$08

SPHXBM1C  DB      $08,$08,$03,$08,$08,$03,$08,$08
          DB      $03,$08,$08,$03,$08,$08,$03,$08
          DB      $08,$03,$08,$04,$03,$08,$08,$03
          DB      $08,$08,$03,$08,$08,$03,$08,$08

FLASHT1C  DB      $0D,$0D,$0D,$04,$0D,$0D,$04,$0D
          DB      $0D,$0D,$0D,$04,$0D,$0D,$04,$0D

**


          END
*         SPHINX.S--SVEX.S

          ZERODEF

*         ALIEN STUFF
          ORG     $FF80                  ; $FF80 - $FFF7 RESERVED FOR ALIEN
ALIEN     DB      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
          DB      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
          DB      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
          DB      0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
                  ;120 FOR ALIEN

* VECTORS FOR STARTUP
          ORG     $FFF8
          DB      $FF,$87
          DB      L(HANDLER),H(HANDLER)  ;DLI HANDLER    NMI
          DB      L(STARTUP),H(STARTUP)  ; STARTUP VECTOR
          DB      0,0                    ;IRQ VECTOR NOT USED

          END
********SSCROBJ.S NEW SCROLLING OBJECT SHIT

          ZERODEF

          RSEG    CODEF

; SCRLOAD SCANS THE SCROLLING OBJECT BUFFER FOR STAMPS THAT ARE READY TO BE
; LOADED, AND PUTS THEM INTO THE LOADER TABLES.
; IT IS RUN ONCE EVERY COARSE SCROLL.

SCRBUFSZ  EQU     10                     ; SIZE OF SCROLLING OBJECT BUFFER
INITVP    EQU     -15                    ; INITIAL VP FOR MOST OBJECTS

SCRLDRTS  RTS

SCRLOAD   BIT     GCOARSE
          BPL     SCRLDRTS               ; DO ONLY ON COARSE SCROLLS
          LDX     #SCRBUFSZ
SCRLDLP   DEX
          BMI     SCRLDRTS               ; ALL DONE
          LDY     STAMPID,X
          BMI     SCRLDLP                ; NOT AN ACTIVE BUFFER SLOT
          DEC     ZONESBK,X
          BPL     SCRLDLP                ; NOT TIME YET

          STX     TEMP0                  ; SAVE X SINCE WE ARE LOADING THIS ONE
          LDA     HPOS,X
          STA     TEMP1                  ; WE NEED THE HPOS ALL OVER THE PLACE

          JSR     GETASLOT               ; GET SLOT NUMBER FOR OBJECT IN X
          BPL     FUCKTHIS               ; NO SLOT AVAILABLE SO PUNT
          JMP     SCRPUNT

FUCKTHIS  LDA     SCRSL,Y                ; START FILLING IN LOADER TABLES
          STA     SLTBL,X
          LDA     SCRSH,Y
          STA     SHTBL,X
          LDA     SCRSM,Y
          STA     SMTBL,X
          LDA     SCRPW,Y
          STA     PWTBL,X

          LDA     TEMP1                  ; HPOS
          CLC
          ADC     SCRHOFF,Y
          SEC
          SBC     SCRDELTA
          STA     HPTBL,X

          LDA     SCRVP,Y
          CLC
          ADC     SCRDELTA
          STA     VPTBL,X

          LDA     SCRY,Y
          STA     YTBL,X

          LDA     SCRCOL,Y
          STA     COLSTAT,X
          BEQ     NOCOLBOX               ; NO COLISION BOX FOR THIS STAMP
          LDA     TEMP1                  ; HPOS
          LSR     A
          CLC
          ADC     SCRXOFF,Y              ; ARE THESE AFFECTED BY SCRDELTA ????
          STA     COLX1,X
          CLC
          ADC     SCRWDTH,Y
          STA     COLX2,X
          LDA     TEMP1                  ; HPOS
          LSR     A
          CLC
          ADC     SCRZOFF,Y
          STA     COLZ1,X
          CLC
          ADC     SCRDPTH,Y
          STA     COLZ2,X
          LDA     SCRYOFF,Y
          STA     COLY1,X
          CLC
          ADC     SCRHGHT,Y
          STA     COLY2,X

NOCOLBOX  LDA     SCRDX,Y
          CMP     #$FF
          BEQ     AHIERO
          SEC
          SBC     SCRDELTA
AHIERO    STA     TEMP6
          CLC
          ADC     SCRDD,Y                ; CALCULATE DF
          STA     TEMP10

          JSR     OBJINS                 ; PUT IT IN THE LINKED LIST

          CPY     #20
          BNE     DISP1
          JSR     MINIINIT
          JMP     SCRPUNT
DISP1     CPY     #22
          BNE     DISP2
          JSR     FIREINIT
          JMP     SCRPUNT
DISP2     CPY     #30
          BNE     DISP3
          JSR     SXFLINIT
          JMP     SCRPUNT
DISP3     CPY     #31
          BNE     SCRPUNT
          JSR     SXFHINIT

SCRPUNT   LDX     TEMP0                  ; GET SET TO CONTINUE
          LDA     #-1
          STA     STAMPID,X              ; MARK BUFFER SLOT AS UNUSED
          INC     FRBUFPTR               ; PUSH BUFFER SLOT BACK ONTO STACK
          LDY     FRBUFPTR
          TXA
          STA     FRBUFSTK,Y
          JMP     SCRLDLP

SCRSL
          DB      L(CANEH)               ; HIERO 1                       0
          DB      L(MANWSTAF)            ; HIERO 2                       1
          DB      L(FEATHER)             ; HIERO 3                       2
          DB      L(EYEH)                ; HIERO 4                       3
          DB      L(AHNKH)               ; HIERO 5                       4
          DB      L(BIRDH)               ; HIERO 6                       5
          DB      L(SUNOWTRH)            ; HIERO 7                       6
          DB      L(BOWLH)               ; HIERO 8                       7
          DB      L(GEM)                 ; JEWEL 1                       8
          DB      L(EGG)                 ; JEWEL 2                       9
          DB      L(BAR)                 ; JEWEL 3                      10
          DB      L(BIGPYR0)             ; SM PYR BOT                   11
          DB      L(BIGPYR1)             ; SM PYR TOP                   12
          DB      L(OPEPYR0)             ; LG PYR BOT                   13
          DB      L(OPEPYR1)             ; LG PYR MID                   14
          DB      L(OPEPYR2)             ; LG PYR TOP                   15
          DB      L(OBELISK0)            ; OBELISK BOT                  16
          DB      L(OBELISK1)            ; OBELISK MID                  17
          DB      L(OBELISK2)            ; OBELISK TOP                  18
          DB      L(MINISPH0)            ; MINI BOT                     19
          DB      L(MINISPH1)            ; MINI TOP                     20
          DB      L(POT)                 ; FIRE POT                     21
          DB      L(TIP1)                ; FIRE TIP                     22
          DB      L(SPHINXL1)            ; SPHINX LEFT BOT              23
          DB      L(SPHINXL2)            ; SPHINX LEFT                  24
          DB      L(SPHINXL3)            ; SPHINX LEFT                  25
          DB      L(SPHINXL4)            ; SPHINX LEFT TOP              26
          DB      L(SPHINXR2)            ; SPHINX RIGHT BOT             27
          DB      L(SPHINXR3)            ; SPHINX RIGHT                 28
          DB      L(SPHINXR4)            ; SPHINX RIGHT TOP             29
          DB      L(SPFACE1L)            ; SPHINX FACE BOT              30
          DB      L(SPFACE1H)            ; SPHINX FACE TOP              31

SCRSH
          DB      H(CANEH)               ; HIERO 1
          DB      H(MANWSTAF)            ; HIERO 2
          DB      H(FEATHER)             ; HIERO 3
          DB      H(EYEH)                ; HIERO 4
          DB      H(AHNKH)               ; HIERO 5
          DB      H(BIRDH)               ; HIERO 6
          DB      H(SUNOWTRH)            ; HIERO 7
          DB      H(BOWLH)               ; HIERO 8
          DB      H(GEM)                 ; JEWEL 1
          DB      H(EGG)                 ; JEWEL 2
          DB      H(BAR)                 ; JEWEL 3
          DB      H(BIGPYR0)             ; SM PYR BOT
          DB      H(BIGPYR1)             ; SM PYR TOP
          DB      H(OPEPYR0)             ; LG PYR BOT
          DB      H(OPEPYR1)             ; LG PYR MID
          DB      H(OPEPYR2)             ; LG PYR TOP
          DB      H(OBELISK0)            ; OBELISK BOT
          DB      H(OBELISK1)            ; OBELISK MID
          DB      H(OBELISK2)            ; OBELISK TOP
          DB      H(MINISPH0)            ; MINI BOT
          DB      H(MINISPH1)            ; MINI TOP
          DB      H(POT)                 ; FIRE POT
          DB      H(TIP1)                ; FIRE TIP
          DB      H(SPHINXL1)            ; SPHINX LEFT BOT
          DB      H(SPHINXL2)            ; SPHINX LEFT
          DB      H(SPHINXL3)            ; SPHINX LEFT
          DB      H(SPHINXL4)            ; SPHINX LEFT TOP
          DB      H(SPHINXR2)            ; SPHINX RIGHT BOT
          DB      H(SPHINXR3)            ; SPHINX RIGHT
          DB      H(SPHINXR4)            ; SPHINX RIGHT TOP
          DB      H(SPFACE1L)            ; SPHINX FACE BOT
          DB      H(SPFACE1H)            ; SPHINX FACE TOP

SCRSM
          DB      H(CANEH+$1100-$1000)    ; HIERO 1
          DB      H(MANWSTAF+$1100-$1000) ; HIERO 2
          DB      H(FEATHER+$1100-$1000)  ; HIERO 3
          DB      H(EYEH+$1100-$1000)     ; HIERO 4
          DB      H(AHNKH+$1100-$1000)    ; HIERO 5
          DB      H(BIRDH+$1100-$1000)    ; HIERO 6
          DB      H(SUNOWTRH+$1100-$1000) ; HIERO 7
          DB      H(BOWLH+$1100-$1000)    ; HIERO 8
          DB      H(GEM+$1100-$1000)      ; JEWEL 1
          DB      H(EGG+$1100-$1000)      ; JEWEL 2
          DB      H(BAR+$1100-$1000)      ; JEWEL 3
          DB      H(BIGPYR0+$1100-$1000)  ; SM PYR BOT
          DB      H(BIGPYR1+$1100-$1000)  ; SM PYR TOP
          DB      H(OPEPYR0+$1100-$1000)  ; LG PYR BOT
          DB      H(OPEPYR1+$1100-$1000)  ; LG PYR MID
          DB      H(OPEPYR2+$1100-$1000)  ; LG PYR TOP
          DB      H(OBELISK0+$1100-$1000) ; OBELISK BOT
          DB      H(OBELISK1+$1100-$1000) ; OBELISK MID
          DB      H(OBELISK2+$1100-$1000) ; OBELISK TOP
          DB      H(MINISPH0+$1100-$1000) ; MINI BOT
          DB      H(MINISPH1+$1100-$1000) ; MINI TOP
          DB      H(POT+$1100-$1000)      ; FIRE POT
          DB      H(TIP1+$1100-$100)      ; FIRE TIP
          DB      H(SPHINXL1+$1100-$1000) ; SPHINX LEFT BOT
          DB      H(SPHINXL2+$1100-$1000) ; SPHINX LEFT
          DB      H(SPHINXL3+$1100-$1000) ; SPHINX LEFT
          DB      H(SPHINXL4+$1100-$1000) ; SPHINX LEFT TOP
          DB      H(SPHINXR2+$1100-$1000) ; SPHINX RIGHT BOT
          DB      H(SPHINXR3+$1100-$1000) ; SPHINX RIGHT
          DB      H(SPHINXR4+$1100-$1000) ; SPHINX RIGHT TOP
          DB      H(SPFACE1L+$1100-$1000) ; SPHINX FACE BOT
          DB      H(SPFACE1H+$1100-$1000) ; SPHINX FACE TOP

SCRPW
          DB      $7E                    ; HIERO 1
          DB      $7D                    ; HIERO 2
          DB      $7E                    ; HIERO 3
          DB      $7D                    ; HIERO 4
          DB      $7D                    ; HIERO 5
          DB      $7E                    ; HIERO 6
          DB      $7D                    ; HIERO 7
          DB      $7D                    ; HIERO 8
          DB      $BE                    ; JEWEL 1
          DB      $9E                    ; JEWEL 2
          DB      $7D                    ; JEWEL 3
          DB      $7C                    ; SM PYR BOT
          DB      $7E                    ; SM PYR TOP
          DB      $77                    ; LG PYR BOT
          DB      $77                    ; LG PYR MID
          DB      $79                    ; LG PYR TOP
          DB      $7E                    ; OBELISK BOT
          DB      $7E                    ; OBELISK MID
          DB      $7E                    ; OBELISK TOP
          DB      $F8                    ; MINI BOT
          DB      $F8                    ; MINI TOP
          DB      $FE                    ; FIRE POT
          DB      $9E                    ; FIRE TIP
          DB      $F7                    ; SPHINX LEFT BOT
          DB      $F7                    ; SPHINX LEFT
          DB      $F7                    ; SPHINX LEFT
          DB      $F7                    ; SPHINX LEFT TOP
          DB      $FA                    ; SPHINX RIGHT BOT
          DB      $FA                    ; SPHINX RIGHT
          DB      $FA                    ; SPHINX RIGHT TOP
          DB      $FD                    ; SPHINX FACE BOT
          DB      $FD                    ; SPHINX FACE TOP

SCRHOFF
          DB      0                      ; HIERO 1
          DB      0                      ; HIERO 2
          DB      0                      ; HIERO 3
          DB      0                      ; HIERO 4
          DB      0                      ; HIERO 5
          DB      0                      ; HIERO 6
          DB      0                      ; HIERO 7
          DB      0                      ; HIERO 8
          DB      0                      ; JEWEL 1
          DB      0                      ; JEWEL 2
          DB      0                      ; JEWEL 3
          DB      0                      ; SM PYR BOT
          DB      4-16                   ; SM PYR TOP
          DB      0                      ; LG PYR BOT
          DB      0-16                   ; LG PYR MID
          DB      4-32                   ; LG PYR TOP
          DB      0                      ; OBELISK BOT
          DB      0-16                   ; OBELISK MID
          DB      0-32                   ; OBELISK TOP
          DB      0                      ; MINI BOT
          DB      0-16                   ; MINI TOP
          DB      0                      ; FIRE POT
          DB      0                      ; FIRE TIP
          DB      0                      ; SPHINX LEFT BOT
          DB      0-16                   ; SPHINX LEFT
          DB      0-32                   ; SPHINX LEFT
          DB      0-48                   ; SPHINX LEFT TOP
          DB      35-16                  ; SPHINX RIGHT BOT
          DB      35-32                  ; SPHINX RIGHT
          DB      35-48                  ; SPHINX RIGHT TOP
          DB      8-16                   ; SPHINX FACE BOT
          DB      8-32                   ; SPHINX FACE TOP

SCRVP
          DB      INITVP                 ; HIERO 1
          DB      INITVP                 ; HIERO 2
          DB      INITVP                 ; HIERO 3
          DB      INITVP                 ; HIERO 4
          DB      INITVP                 ; HIERO 5
          DB      INITVP                 ; HIERO 6
          DB      INITVP                 ; HIERO 7
          DB      INITVP                 ; HIERO 8
          DB      INITVP                 ; JEWEL 1
          DB      INITVP                 ; JEWEL 2
          DB      INITVP                 ; JEWEL 3
          DB      INITVP                 ; SM PYR BOT
          DB      INITVP                 ; SM PYR TOP
          DB      INITVP                 ; LG PYR BOT
          DB      INITVP                 ; LG PYR MID
          DB      INITVP                 ; LG PYR TOP
          DB      INITVP                 ; OBELISK BOT
          DB      INITVP                 ; OBELISK MID
          DB      INITVP                 ; OBELISK TOP
          DB      INITVP                 ; MINI BOT
          DB      INITVP                 ; MINI TOP
          DB      INITVP-3               ; FIRE POT
          DB      INITVP-2               ; FIRE TIP
          DB      INITVP                 ; SPHINX LEFT BOT
          DB      INITVP                 ; SPHINX LEFT
          DB      INITVP                 ; SPHINX LEFT
          DB      INITVP                 ; SPHINX LEFT TOP
          DB      INITVP-4               ; SPHINX RIGHT BOT
          DB      INITVP-4               ; SPHINX RIGHT
          DB      INITVP-4               ; SPHINX RIGHT TOP
          DB      INITVP+2               ; SPHINX FACE BOT
          DB      INITVP+2               ; SPHINX FACE TOP

SCRY
          DB      0                      ; HIERO 1
          DB      0                      ; HIERO 2
          DB      0                      ; HIERO 3
          DB      0                      ; HIERO 4
          DB      0                      ; HIERO 5
          DB      0                      ; HIERO 6
          DB      0                      ; HIERO 7
          DB      0                      ; HIERO 8
          DB      1                      ; JEWEL 1
          DB      1                      ; JEWEL 2
          DB      1                      ; JEWEL 3
          DB      1                      ; SM PYR BOT
          DB      2                      ; SM PYR TOP
          DB      1                      ; LG PYR BOT
          DB      2                      ; LG PYR MID
          DB      3                      ; LG PYR TOP
          DB      1                      ; OBELISK BOT
          DB      2                      ; OBELISK MID
          DB      3                      ; OBELISK TOP
          DB      1                      ; MINI BOT
          DB      2                      ; MINI TOP
          DB      1                      ; FIRE POT
          DB      16                     ; FIRE TIP
          DB      1                      ; SPHINX LEFT BOT
          DB      2                      ; SPHINX LEFT
          DB      3                      ; SPHINX LEFT
          DB      4                      ; SPHINX LEFT TOP
          DB      1                      ; SPHINX RIGHT BOT
          DB      2                      ; SPHINX RIGHT
          DB      3                      ; SPHINX RIGHT TOP
          DB      2                      ; SPHINX FACE BOT
          DB      3                      ; SPHINX FACE TOP

SCRCOL
          DB      HIEROCOL               ; HIERO 1
          DB      HIEROCOL+1             ; HIERO 2
          DB      HIEROCOL+2             ; HIERO 3
          DB      HIEROCOL+3             ; HIERO 4
          DB      HIEROCOL+4             ; HIERO 5
          DB      HIEROCOL+5             ; HIERO 6
          DB      HIEROCOL+6             ; HIERO 7
          DB      HIEROCOL+7             ; HIERO 8
          DB      TREASCOL               ; JEWEL 1
          DB      TREASCOL+1             ; JEWEL 2
          DB      TREASCOL+2             ; JEWEL 3
          DB      PASSVCOL               ; SM PYR BOT
          DB      PASSVCOL               ; SM PYR TOP
          DB      PASSVCOL               ; LG PYR BOT
          DB      PASSVCOL               ; LG PYR MID
          DB      PASSVCOL               ; LG PYR TOP
          DB      PASSVCOL               ; OBELISK BOT
          DB      PASSVCOL               ; OBELISK MID
          DB      PASSVCOL               ; OBELISK TOP
          DB      PASSVCOL               ; MINI BOT
          DB      MINICOL                ; MINI TOP
          DB      PASSVCOL               ; FIRE POT
          DB      FIRECOL                ; FIRE TIP
          DB      PASSVCOL               ; SPHINX LEFT BOT
          DB      PASSVCOL               ; SPHINX LEFT
          DB      PASSVCOL               ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      PASSVCOL               ; SPHINX RIGHT BOT
          DB      PASSVCOL               ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      SPHNXCOL               ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRXOFF
          DB      -7                     ; HIERO 1
          DB      -7                     ; HIERO 2
          DB      -7                     ; HIERO 3
          DB      -7                     ; HIERO 4
          DB      -7                     ; HIERO 5
          DB      -7                     ; HIERO 6
          DB      -7                     ; HIERO 7
          DB      -7                     ; HIERO 8
          DB      -4                     ; JEWEL 1
          DB      -4                     ; JEWEL 2
          DB      -4                     ; JEWEL 3
          DB      -4                     ; SM PYR BOT
          DB      -2                     ; SM PYR TOP
          DB      -8                     ; LG PYR BOT
          DB      -6                     ; LG PYR MID
          DB      -3                     ; LG PYR TOP
          DB      -3                     ; OBELISK BOT
          DB      -3                     ; OBELISK MID
          DB      -2                     ; OBELISK TOP
          DB      -3                     ; MINI BOT
          DB      -2                     ; MINI TOP
          DB      -2                     ; FIRE POT
          DB      -3                     ; FIRE TIP
          DB      -10                    ; SPHINX LEFT BOT
          DB      4                      ; SPHINX LEFT
          DB      -9                     ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      -12                    ; SPHINX RIGHT BOT
          DB      -9                     ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      -2                     ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRWDTH
          DB      12                     ; HIERO 1
          DB      12                     ; HIERO 2
          DB      12                     ; HIERO 3
          DB      12                     ; HIERO 4
          DB      12                     ; HIERO 5
          DB      12                     ; HIERO 6
          DB      12                     ; HIERO 7
          DB      12                     ; HIERO 8
          DB      6                      ; JEWEL 1
          DB      6                      ; JEWEL 2
          DB      6                      ; JEWEL 3
          DB      8                      ; SM PYR BOT
          DB      4                      ; SM PYR TOP
          DB      17                     ; LG PYR BOT
          DB      12                     ; LG PYR MID
          DB      6                      ; LG PYR TOP
          DB      6                      ; OBELISK BOT
          DB      6                      ; OBELISK MID
          DB      4                      ; OBELISK TOP
          DB      10                     ; MINI BOT
          DB      8                      ; MINI TOP
          DB      5                      ; FIRE POT
          DB      7                      ; FIRE TIP
          DB      6                      ; SPHINX LEFT BOT
          DB      6                      ; SPHINX LEFT
          DB      18                     ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      24                     ; SPHINX RIGHT BOT
          DB      18                     ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      4                      ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRYOFF
          DB      0                      ; HIERO 1
          DB      0                      ; HIERO 2
          DB      0                      ; HIERO 3
          DB      0                      ; HIERO 4
          DB      0                      ; HIERO 5
          DB      0                      ; HIERO 6
          DB      0                      ; HIERO 7
          DB      0                      ; HIERO 8
          DB      1                      ; JEWEL 1
          DB      1                      ; JEWEL 2
          DB      1                      ; JEWEL 3
          DB      1                      ; SM PYR BOT
          DB      8                      ; SM PYR TOP
          DB      1                      ; LG PYR BOT
          DB      11                     ; LG PYR MID
          DB      22                     ; LG PYR TOP
          DB      1                      ; OBELISK BOT
          DB      20                     ; OBELISK MID
          DB      39                     ; OBELISK TOP
          DB      1                      ; MINI BOT
          DB      9                      ; MINI TOP
          DB      1                      ; FIRE POT
          DB      16                     ; FIRE TIP
          DB      1                      ; SPHINX LEFT BOT
          DB      1                      ; SPHINX LEFT
          DB      1                      ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      1                      ; SPHINX RIGHT BOT
          DB      1                      ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      SPHNXNSY               ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRHGHT
          DB      1                      ; HIERO 1
          DB      1                      ; HIERO 2
          DB      1                      ; HIERO 3
          DB      1                      ; HIERO 4
          DB      1                      ; HIERO 5
          DB      1                      ; HIERO 6
          DB      1                      ; HIERO 7
          DB      1                      ; HIERO 8
          DB      8                      ; JEWEL 1
          DB      8                      ; JEWEL 2
          DB      8                      ; JEWEL 3
          DB      8                      ; SM PYR BOT
          DB      9                      ; SM PYR TOP
          DB      12                     ; LG PYR BOT
          DB      13                     ; LG PYR MID
          DB      12                     ; LG PYR TOP
          DB      21                     ; OBELISK BOT
          DB      21                     ; OBELISK MID
          DB      8                      ; OBELISK TOP
          DB      12                     ; MINI BOT
          DB      11                     ; MINI TOP
          DB      15                     ; FIRE POT
          DB      2                      ; FIRE TIP
          DB      12                     ; SPHINX LEFT BOT
          DB      12                     ; SPHINX LEFT
          DB      42                     ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      12                     ; SPHINX RIGHT BOT
          DB      25                     ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      4                      ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRZOFF
          DB      NUMBER+6               ; HIERO 1
          DB      NUMBER+6               ; HIERO 2
          DB      NUMBER+6               ; HIERO 3
          DB      NUMBER+6               ; HIERO 4
          DB      NUMBER+6               ; HIERO 5
          DB      NUMBER+6               ; HIERO 6
          DB      NUMBER+6               ; HIERO 7
          DB      NUMBER+6               ; HIERO 8
          DB      NUMBER+4               ; JEWEL 1
          DB      NUMBER+4               ; JEWEL 2
          DB      NUMBER+4               ; JEWEL 3
          DB      NUMBER+4               ; SM PYR BOT
          DB      NUMBER+6-16            ; SM PYR TOP
          DB      NUMBER+8               ; LG PYR BOT
          DB      NUMBER+10-16           ; LG PYR MID
          DB      NUMBER+13-32           ; LG PYR TOP
          DB      NUMBER+2               ; OBELISK BOT
          DB      NUMBER+2-16            ; OBELISK MID
          DB      NUMBER+2-32            ; OBELISK TOP
          DB      NUMBER+6               ; MINI BOT
          DB      NUMBER+4-16            ; MINI TOP
          DB      NUMBER+5               ; FIRE POT
          DB      NUMBER+4               ; FIRE TIP
          DB      NUMBER+9               ; SPHINX LEFT BOT
          DB      NUMBER+9-16            ; SPHINX LEFT
          DB      NUMBER+16-32           ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      NUMBER+17              ; SPHINX RIGHT BOT
          DB      NUMBER+10-16           ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      NUMBER+12-16           ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRDPTH
          DB      12                     ; HIERO 1
          DB      12                     ; HIERO 2
          DB      12                     ; HIERO 3
          DB      12                     ; HIERO 4
          DB      12                     ; HIERO 5
          DB      12                     ; HIERO 6
          DB      12                     ; HIERO 7
          DB      12                     ; HIERO 8
          DB      9                      ; JEWEL 1
          DB      9                      ; JEWEL 2
          DB      9                      ; JEWEL 3
          DB      8                      ; SM PYR BOT
          DB      4                      ; SM PYR TOP
          DB      17                     ; LG PYR BOT
          DB      12                     ; LG PYR MID
          DB      6                      ; LG PYR TOP
          DB      4                      ; OBELISK BOT
          DB      4                      ; OBELISK MID
          DB      2                      ; OBELISK TOP
          DB      17                     ; MINI BOT
          DB      6                      ; MINI TOP
          DB      5                      ; FIRE POT
          DB      7                      ; FIRE TIP
          DB      12                     ; SPHINX LEFT BOT
          DB      12                     ; SPHINX LEFT
          DB      20                     ; SPHINX LEFT
          DB      0                      ; SPHINX LEFT TOP
          DB      20                     ; SPHINX RIGHT BOT
          DB      26                     ; SPHINX RIGHT
          DB      0                      ; SPHINX RIGHT TOP
          DB      5                      ; SPHINX FACE BOT
          DB      0                      ; SPHINX FACE TOP

SCRDX
          DB      $FF                    ; HIERO 1
          DB      $FF                    ; HIERO 2
          DB      $FF                    ; HIERO 3
          DB      $FF                    ; HIERO 4
          DB      $FF                    ; HIERO 5
          DB      $FF                    ; HIERO 6
          DB      $FF                    ; HIERO 7
          DB      $FF                    ; HIERO 8
          DB      (2*NUMBER)+DXADJ       ; JEWEL 1
          DB      (2*NUMBER)+DXADJ       ; JEWEL 2
          DB      (2*NUMBER)+DXADJ       ; JEWEL 3
          DB      (2*NUMBER)+DXADJ       ; SM PYR BOT
          DB      (2*NUMBER)+DXADJ-16    ; SM PYR TOP
          DB      (2*NUMBER)+DXADJ       ; LG PYR BOT
          DB      (2*NUMBER)+DXADJ-16    ; LG PYR MID
          DB      (2*NUMBER)+DXADJ-32    ; LG PYR TOP
          DB      (2*NUMBER)+DXADJ       ; OBELISK BOT
          DB      (2*NUMBER)+DXADJ-16    ; OBELISK MID
          DB      (2*NUMBER)+DXADJ-32    ; OBELISK TOP
          DB      (2*NUMBER)+DXADJ       ; MINI BOT
          DB      (2*NUMBER)+DXADJ-16    ; MINI TOP
          DB      (2*NUMBER)+DXADJ+1     ; FIRE POT
          DB      (2*NUMBER)+DXADJ       ; FIRE TIP
          DB      (2*NUMBER)+DXADJ       ; SPHINX LEFT BOT
          DB      (2*NUMBER)+DXADJ-8     ; SPHINX LEFT
          DB      (2*NUMBER)+DXADJ-16    ; SPHINX LEFT
          DB      (2*NUMBER)+DXADJ-32    ; SPHINX LEFT TOP
          DB      (2*NUMBER)+DXADJ       ; SPHINX RIGHT BOT
          DB      (2*NUMBER)+DXADJ-16    ; SPHINX RIGHT
          DB      (2*NUMBER)+DXADJ-32    ; SPHINX RIGHT TOP
          DB      (2*NUMBER)+DXADJ       ; SPHINX FACE BOT
          DB      (2*NUMBER)+DXADJ-16    ; SPHINX FACE TOP

SCRDD
          DB      0                      ; HIERO 1
          DB      0                      ; HIERO 2
          DB      0                      ; HIERO 3
          DB      0                      ; HIERO 4
          DB      0                      ; HIERO 5
          DB      0                      ; HIERO 6
          DB      0                      ; HIERO 7
          DB      0                      ; HIERO 8
          DB      6                      ; JEWEL 1
          DB      6                      ; JEWEL 2
          DB      6                      ; JEWEL 3
          DB      8                      ; SM PYR BOT
          DB      8                      ; SM PYR TOP
          DB      16                     ; LG PYR BOT
          DB      16                     ; LG PYR MID
          DB      16                     ; LG PYR TOP
          DB      4                      ; OBELISK BOT
          DB      4                      ; OBELISK MID
          DB      4                      ; OBELISK TOP
          DB      18                     ; MINI BOT
          DB      18                     ; MINI TOP
          DB      4                      ; FIRE POT
          DB      6                      ; FIRE TIP
          DB      19                     ; SPHINX LEFT BOT
          DB      19                     ; SPHINX LEFT
          DB      19                     ; SPHINX LEFT
          DB      19                     ; SPHINX LEFT TOP
          DB      19                     ; SPHINX RIGHT BOT
          DB      19                     ; SPHINX RIGHT
          DB      19                     ; SPHINX RIGHT TOP
          DB      10                     ; SPHINX FACE BOT
          DB      10                     ; SPHINX FACE TOP

; SCRBUF - ROUTINE TO LOAD THE SCROLLING OBJECT BUFFER WITH ALL THE STAMPS
;         FOR AN OBJECT.

;         A = HORIZONTAL POSITION FOR THE OBJECT
;         X = OBJID FOR THE OBJECT

;         TRASHES A, TEMP0, TEMP1, TEMP2

SCRBUFDN  LDX     TEMP1
          RTS

SCRBUF    STA     TEMP0                  ; SAVE HPOS FOR LATER
          STX     TEMP1
          LDA     FRBUFPTR
          CMP     BUFSIZE,X              ; NUMBER OF BUFFER SLOTS NEEDED
          BCC     SCRBUFDN               ; NO ROOM IN BUFFER
          LDA     BUFSIZE,X
          STA     TEMP2
          LDY     BUFSTART,X
SCRBUFLP  DEC     TEMP2                  ; NUMBER OF PEICES LEFT
          BMI     SCRBUFDN               ; DONE WHEN NEGATIVE
          LDX     FRBUFPTR               ; STACK POINTER FOR BUFFER LOCATIONS
          LDA     FRBUFSTK,X
          TAX
          TYA                            ; INDEX IS STAMP ID
          STA     STAMPID,X
          LDA     BUFZBK,Y
          STA     ZONESBK,X
          LDA     TEMP0
          STA     HPOS,X
          DEC     FRBUFPTR               ; HAVE JUST POPPED BUFFER STACK
BUFTRAP   BMI     BUFTRAP                ; TRAP FOR BUFFER STACK UNDERFLOW
          INY
          BPL     SCRBUFLP               ; ALWAYS

BUFSTART  ; THIS TABLE CONTAINS THE BUFFER DATA STARTING INDEX FOR EACH OBJECT
          DB      0                      ; HIERO 1           0
          DB      1                      ; HIERO 2           1
          DB      2                      ; HIERO 3           2
          DB      3                      ; HIERO 4           3
          DB      4                      ; HIERO 5           4
          DB      5                      ; HIERO 6           5
          DB      6                      ; HIERO 7           6
          DB      7                      ; HIERO 8           7
          DB      8                      ; JEWEL 1           8
          DB      9                      ; JEWEL 2           9
          DB      10                     ; JEWEL 3          10
          DB      11                     ; SM PYR           11
          DB      13                     ; LG PYR           12
          DB      16                     ; OBELISK          13
          DB      19                     ; MINI SPHINX      14
          DB      21                     ; FIRE POT         15
          DB      23                     ; BIG SPHINX       16

BUFSIZE   ; THIS TABLE CONTAINS THE NUMBER OF PEICES IN EACH OBJECT
          DB      1                      ; HIERO 1           0
          DB      1                      ; HIERO 2           1
          DB      1                      ; HIERO 3           2
          DB      1                      ; HIERO 4           3
          DB      1                      ; HIERO 5           4
          DB      1                      ; HIERO 6           5
          DB      1                      ; HIERO 7           6
          DB      1                      ; HIERO 8           7
          DB      1                      ; JEWEL 1           8
          DB      1                      ; JEWEL 2           9
          DB      1                      ; JEWEL 3          10
          DB      2                      ; SM PYR           11
          DB      3                      ; LG PYR           12
          DB      3                      ; OBELISK          13
          DB      2                      ; MINI SPHINX      14
          DB      2                      ; FIRE POT         15
          DB      9                      ; BIG SPHINX       16

BUFZBK    ; THIS TABLE CONTAINS THE ZONESBK FOR EACH STAMP
          DB      0                      ; HIERO 1
          DB      0                      ; HIERO 2
          DB      0                      ; HIERO 3
          DB      0                      ; HIERO 4
          DB      0                      ; HIERO 5
          DB      0                      ; HIERO 6
          DB      0                      ; HIERO 7
          DB      0                      ; HIERO 8
          DB      0                      ; JEWEL 1
          DB      0                      ; JEWEL 2
          DB      0                      ; JEWEL 3
          DB      0                      ; SM PYR
          DB      1
          DB      0                      ; LG PYR
          DB      1
          DB      2
          DB      0                      ; OBELISK
          DB      1
          DB      2
          DB      0                      ; MINI SPHINX
          DB      1
          DB      0                      ; FIRE POT
          DB      0
          DB      0                      ; BIG SPHINX
          DB      1
          DB      2
          DB      3
          DB      1
          DB      2
          DB      3
          DB      1
          DB      2

          END
*         SPHINX--SGAME.S
          RSEG    CODEE

          ZERODEF

* THIS ROUTINE DRIVES THE BIRD AND ITS SHOTS.  IT HANDLES ANIMATING THE BIRD
* THROUGH ITS STATE MACHINE, COLLISIONS FOR BIRD, MOVING AND GENERATING SHOTS,
* AND THEIR COLLISIONS.  IT BRINGS BIRD BACK TO LIFE AND SUCH.

ZBIRDZ    EQU     80                     ;Z COORDINATE OF BIRD
ZXLIMLOW  EQU     56                     ;LIMITS ON X MOTION
ZXLIMHI   EQU     121
ZYLIMLOW  EQU     5                      ;Y WHEN BIRD ON GROUND
ZYLIMHI   EQU     45                     ;LIMIT ON Y MOTION

*         GAME
GAME
          LDA     #0                     ;CLEAR MOVEMENT FLAG
          STA     TEMP7                  ; MOVEMENT FLAG IS TEMP7 (OBVIOUSLY)

          LDA     DEATH                  ;DON'T READ JOYSTICK WHEN BIRD IS DEAD
          BEQ     LIVE
          JMP     DIE                    ;INSTEAD, GO TO DEAD BIRD HANDLER


*         READ JOYSTICK OR SIMULATED JOYSTICK
LIVE
          LDX     PLAYER
          LDA     RIGHTBUT,X             ;CHECK FIRE BUTTON FOR POWER
          BMI     STKCHK

          JSR     GIVPOWER               ;RIGHT BUTTON PRESSED SO POWER???

STKCHK    BIT     AUTOPLAY               ;AUTOPLAY MODE??
          BPL     LDASWCHA               ;IF NO AUTOPLAY, LOAD JOYSTICK

          LDA     MAINCNT                ;DO WE CHANGE INPUT VECTOR?
          AND     #$1F                   ;CHANGE INPUT EVERY 32 MAINCNTS

          BEQ     THIS2                  ;YES, GOTO THIS2
          LDA     IOSIM                  ;NO JUST USE IOSIM AS USUAL
          JMP     LSRA

THIS2     JSR     RANDOM                 ;GENERATE NEW INPUT VECTOR
          AND     #$0F
          TAX                            ;READ VALUE OUT OF TABLE
          LDA     JOYSIM,X
          STA     IOSIM
          BNE     LSRA                   ;WATCHOUT!!!!

LDASWCHA  BIT     WARP
          BPL     LDASWCH1


          LDA     PHASE                  ;SEE IF WARP IS LEGAL
          BEQ     LDAWARP

          LDA     #0                     ;THIS HAPPENS WHEN WE REACH THE SPHINX
          STA     WARP
          BEQ     LDASWCH1

LDAWARP   LDA     #$0D                   ;FORCE CLIMB DURING WARP POWER
          BNE     LDXXTBL


LDASWCH1  LDA     SWCHA                  ; CHECK JOYSTICK
          LDX     PLAYER
          BEQ     LSRA
          AND     #$0F                   ;IF IT AINT 1 THEN ITS 2 SO
          BNE     LDXXTBL                ;JOYSTICK CAN NEVER BE 0

LSRA      LSR     A                      ;LOOK AT PLAYER1 FOR NOW (TOP NIBBLE)
          LSR     A
          LSR     A
          LSR     A


*         TURN BACK ON THOSE BITS THAT ARE TO BE IGNORED
LDXXTBL   LDX     XTBL+ZBIRD             ; SET BITS FOR DIRS HE CANT MOVE
          CPX     #ZXLIMLOW+1            ;BY CHECKING LIMITS OF MOTION
          BCS     CKBIRDXH
          ORA     #4                     ; SET WEST BIT
          BNE     CKBIRDYH

CKBIRDXH  CPX     #ZXLIMHI
          BCC     CKBIRDYH
          ORA     #8                     ; SET EAST BIT

CKBIRDYH  LDX     YTBL+ZBIRD
          CPX     #ZYLIMHI
          BCC     CKBIRDON
          ORA     #2                     ; SET SOUTH BIT

CKBIRDON
          STA     TEMP0                  ;THIS IS "FIXED" JOYSTICK VALUE

;         LDX     YTBL+ZBIRD             ;ALREADY IN X
          CPX     #ZYLIMLOW
          BNE     INTHEAIR

          BIT     SWIMMING
          BPL     CLLTYPE

          BIT     CANTSWIM               ;HACK FOR CANT SWIM POWER
          BPL     SWIMFOO
          LDA     TEMP0
          ORA     #$D                    ;PROHIBIT ANY BUT SOUTH
          STA     TEMP0
SWIMFOO
          LDX     #ZBIRD                 ;BIRD'S OBJECT NUMBER
          LDA     #0                     ;Z OFFSET IS 0

          STA     TEMP4                  ;IF SWIMMING, ENTER GRNDTYPE WITH
          STX     TEMP3                  ;FIXED VP TO AVOID SANDFUCKER MODE
          LDA     VPTBL,X
          SEC
          SBC     #3                     ;VP ADJUST FOR SWIMMING
          JSR     GRNDFLO
          JMP     POSTGTFL

CLLTYPE
          BIT     CANTHOP
          BPL     HOPFOO
          LDA     TEMP0
          ORA     #$D
          STA     TEMP0
HOPFOO
          LDX     #ZBIRD                 ;BIRD'S OBJECT NUMBER
          LDA     #0                     ;Z OFFSET IS 0
          JSR     GRNDTYPE               ; CHECK CHAR UNDER BIRD

POSTGTFL  CMP     #126                   ;A MAGIC NUMBER IF I EVER SAW ONE
          BCC     NOWATER

          LDA     #$80
          STA     SWIMMING

          LDA     TEMP0                  ;JOYSTICK
          CMP     #$F
          BEQ     NOSWIM                 ;ONLY MAKE SWIMMING SOUND WHEN MOVING

          LDA     #SWIM                  ;START SWIM SOUND
          CMP     TUNNUM
          BEQ     JOHNTMPS
          CMP     TUNNUM+1
          BEQ     JOHNTMPS
          JSR     TUNIN

          JMP     JOHNTMPS

INTHEAIR
          BIT     CANTFLY
          BPL     NOWATER
          LDA     #$E
          STA     TEMP0
NOWATER   LDA     SWIMMING
          AND     #$7F
          STA     SWIMMING
NOSWIM    LDA     #SWIM
          JSR     SCRAPONE

JOHNTMPS

          LDX     TEMP0                  ;JOYSTICK
          LDA     JOYTBL,X               ;GET ACTION FROM TABLE

          LDY     YTBL+ZBIRD             ;BIRD'S Y AFFECTS ACTION
          CPY     #5+ZYLIMLOW            ;5 + 4 ARE SPECIAL SYNCHRONIZED STATES
          BCS     NOSWAP
          CPY     #4+ZYLIMLOW
          BEQ     SWAP

                  ;IF Y IS <=3 THEN LOOK TO SEE IF THERE IS WATER

          BIT     SWIMMING               ;WATER ALSO AFFECTS
          BMI     NOSWAP                 ; DON'T SWAP IF OVER WATER

SWAP      LSR     A                      ;SHIFT TO TOP NIBBLE IF OVER WATER
          LSR     A
          LSR     A
          LSR     A

NOSWAP
          AND     #$F
          STA     TEMP1
          LDA     BIRDSTAT
          LSR     A
          LSR     A
          LSR     A
          LSR     A
          TAX                            ;THIS REPLACES THE HUGE ANIM TABLE
          LDA     BIRDATBL,X
          BPL     BADIRECT
          AND     #$7F
          CLC
          ADC     TEMP1
          TAX
          LDA     BIRDAI,X
BADIRECT  STA     TEMP4

          AND     #$1F
          TAY

          LDA     TEMP1                  ;PREPARE X FOR STATE LOOKUP
          ORA     BIRDSTAT               ;ORA ON BIRDSTAT FOR TOP BITS
          TAX

          LDA     BIRDANAD,Y             ;GET POINTER TO GRAPHCS
          STA     SLTBL+ZBIRD

;         LDA     #$3C                   ; PALLETTE 1, WIDTH = 16
 ;        BIT     TEMP4                  ;GET PW FOR SHADOW
  ;       BPL     NOTDUCK                ;DIFFERENT PALLETTE FOR DUCK

   ;      LDA     #$5C                   ; PALLETTE 2, WIDTH = 16

;OTDUCK   STA     PWTBL+ZSHAD

          LDA     SHADANAD,Y             ;GET GRAPHCS FOR SHADOW
          STA     SLTBL+ZSHAD

          STY     TEMP8                  ; SAVE FOR GETTING OFFSETS IN PROJECT

TESTPNT   LDA     STATETBL,X             ;USE STATE TO GET SCROLL RATE
          AND     #$F
          TAY

          LDA     YTBL+ZBIRD
          CMP     #ZYLIMLOW
          BNE     PUNTRUN                ;FOR TAKEOFF

          BIT     SWIMMING
          BMI     PUNTRUN

          LDA     TEMP0
          CMP     #$F
          BEQ     PUNTRUN

          LDA     #$40
          STA     SWIMMING

          LDA     #RUNNING
          CMP     TUNNUM
          BEQ     DOSCROLL
          CMP     TUNNUM+1
          BEQ     DOSCROLL

          JSR     TUNIN
          JMP     DOSCROLL

PUNTRUN
          LDA     #RUNNING
          JSR     SCRAPONE

          LDA     SWIMMING
          AND     #$BF
          STA     SWIMMING

DOSCROLL  LDA     PHASE
          CMP     #2
          BEQ     ZROSCRAT               ;SPHINX IS STOPPED

          CPY     #$F
          BEQ     SAMSCRAT               ;STAY STATE

          CPY     #$E
          BNE     NMLSCRAT               ;NOT HOPPING
          LDA     TEMP0                  ;JOYSTICK VALUE
          CMP     #$07                   ;EAST
          BEQ     ZROSCRAT
          CMP     #$0B                   ;WEST
          BEQ     ZROSCRAT

NMLSCRAT  BIT     WARP
          BPL     NMLSCRA1
          LDA     #$20
          BPL     STRSCRAT

NMLSCRA1  LDA     SCRATBL,Y
          BPL     STRSCRAT               ;NEAR GROUND - ABSOLUTE CONTROL

          BIT     HOVER
          BMI     ZROSCRAT

          STX     TEMP6                  ;SAVE X

          LDX     PLAYER
          LDA     RACK,X

          LDX     #2                     ;MININUM FLYING SCRATE

          CMP     #1
          BCC     BNSSCRAT
          INX

          CMP     #3
          BCC     BNSSCRAT
          INX

          CMP     #7
          BCC     BNSSCRAT
          INX

          CMP     #12
          BCC     BNSSCRAT
          INX

          CMP     #20
          BCC     BNSSCRAT
          INX

BNSSCRAT  TXA
          CLC
          ADC     DIFCULTY

          LDX     PHASE
          CPX     #-2                    ;ACTUAL BONUS
          BNE     ENDSCRAT

          CLC
          ADC     #2

ENDSCRAT  BIT     SPEEDUP
          BPL     ENDSCRA2
          ASL     A
          JMP     ENDSCRA3

ENDSCRA2  LDX     SLOWDOWN
          BPL     ENDSCRA3
          LSR     A

ENDSCRA3  CMP     #3
          BNE     ENDSCRA1
          LDA     #2                     ;SCRATE = 3 LOOKS TOO SHITTY
ENDSCRA1  STA     SCRATE
          LDX     TEMP6                  ;RESTORE X

          LDA     YTBL+ZBIRD
          SEC
          SBC     #ZYLIMLOW
          BEQ     SAMSCRAT               ;ON GROUND

          CMP     SCRATE
          BCS     SAMSCRAT               ;SCRATE OK

          STA     SCRATE                 ;LIMIT SCRATE NEAR GROUND
          BCC     SAMSCRAT               ;ALWAYS

ZROSCRAT  LDA     #0
STRSCRAT  STA     SCRATE

SAMSCRAT  LDA     ADELTBL,Y              ;CHECK FOR CHANGE OF AIMATION
          INC     BIRDACNT
          CMP     BIRDACNT
          BCS     NONEWSTA               ; NOT TIME FOR NEXT ANIMATION

          LDA     #0                     ;DO NEW ANIMATION
          STA     BIRDACNT
          LDA     STATETBL,X             ;TOP OF STATE IS NEW BIRDSTAT
          AND     #$F0
          STA     BIRDSTAT

NONEWSTA  LDA     SCRATE
          LSR     A
          LSR     A
          CLC
          ADC     #2
          STA     TEMP10

          LDA     TEMP0                  ;THIS IS JOYSTICK VALUE
          LDX     YMODTBL,Y              ;CHECK FOR Y MOTION
          BEQ     NONEWY
          BMI     YMOVE

          STX     YTBL+ZBIRD
          LDX     #$FF
          STX     TEMP7                  ; SET MOVEMENT FLAG
          JMP     NONEWY

YMOVE     LSR     A
          BCS     CKUP                   ;LOOK FOR DOWN BIT (NORTH)

          TAX

          LDA     YTBL+ZBIRD
          SEC
          SBC     TEMP10

          BMI     FIXYNEG
          CMP     #ZYLIMLOW+3
          BCS     GOTYDN
FIXYNEG   LDA     #ZYLIMLOW+3

GOTYDN    STA     YTBL+ZBIRD
          TXA

          LDX     #$FF
          STX     TEMP7                  ; SET MOVEMENT FLAG
          LSR     A
          JMP     CKNEWX

CKUP      LSR     A                      ;CHECK FOR UP (SOUTH)
          BCS     CKNEWX

          TAX

          LDA     YTBL+ZBIRD
          CLC
          ADC     TEMP10

          CMP     #ZYLIMHI
          BCC     GOTYUP
          LDA     #ZYLIMHI

GOTYUP    STA     YTBL+ZBIRD
          TXA

          LDX     #$FF
          STX     TEMP7                  ; SET MOVEMENT FLAG
          JMP     CKNEWX

NONEWY    LSR     A                      ;THIS CATCHES A UP IN SHIFTING
          LSR     A

CKNEWX    INC     BIRDXCNT               ;MOVE IN X DIR IN SAME WAY.
          LDX     XDELTBL,Y
          BEQ     PROJ

          CPX     BIRDXCNT
          BCS     PROJ                   ; NOT TIME TO UPDATE X

          LDX     #1                     ;RESET X COUNTER
          STX     BIRDXCNT

          LSR     A                      ;LOOK FOR WEST
          BCS     CKRIGHT

          LDA     XTBL+ZBIRD             ;DO THIS ON WEST
          SEC
          SBC     TEMP10
          STA     XTBL+ZBIRD

          LDX     #$FF
          STX     TEMP7                  ; SET MOVEMENT FLAG
          BMI     PROJ                   ;JMP

CKRIGHT   LSR     A                      ;LOOK FOR EAST
          BCS     PROJ
          LDA     XTBL+ZBIRD             ;DO THIS ON EAST

          CLC
          ADC     TEMP10
          STA     XTBL+ZBIRD

          LDX     #$FF
          STX     TEMP7                  ; SET MOVEMENT FLAG

PROJ      JSR     PROJECT                ;MAP X,Y,Z TO HP,VP


*         COLLISION DETECTION FOR BIRD IS DONE HERE

          BIT     WARP
          BMI     SURVIVE                ;DON'T DETECT COLISIONS DURING WARP

          JSR     DOCOL                  ;DO COLLISION DETECTION
          CMP     #TREASCOL              ;SURVIVE IF ZERO RETURNED OR IF
          BCC     SURVIVE                ;IT HIT A HIERO

          CMP     #FLEACOL               ;WAS THE COLISION WITH A FLEA
          BNE     CC1
          JSR     KILLFLEA               ;IF SO, TAKE HIM WITH US TO THE GRAVE
          JMP     STOP1

CC1       CMP     #SXSHTCOL              ;WAS IT WITH A SPHINX SHOT
          BNE     CC2
          LDA     #0
          STA     SXSHTSTT-SPHXSHOT,X
          JSR     OBJDEL                 ;DELETE SHOT WHICH HIT YOU
          TXA
          CLC
          ADC     #SPXSHTSH-SPHXSHOT
          TAX
          JSR     OBJDEL                 ;DELETE SHADOW AS WELL
          JMP     STOP1

CC2       CMP     #UWECOL                ;WAS IT WITH A UWE
          BNE     CC3
          JSR     KILLUWE                ;KILL UWE
          JMP     STOP1

CC3       CMP     #TREASCOL              ;WAS IT A TREASURE
          BCC     STOP
          CMP     #TREASCOL+3
          BCS     STOP
          JSR     GOTTREAS               ;TAKE CARE OF TREASURE

SURVIVE   LDA     YTBL+ZBIRD             ;CHECK FOR HIERO'S
          CMP     #ZYLIMLOW
          BNE     NOLUCK                 ;BIRD NOT ON GROUND

          JSR     HIERODET               ;SPECIALIZED COLISION DETECT

          BEQ     NOLUCK
          CMP     #TREASCOL
          BCS     NOLUCK
          JSR     GOTHIERO

NOLUCK    JSR     DOSHOTS                ;DO SHOT CODE
          RTS

*         INITIATE DEATH
STOP1
          BIT     INVINCBL
          BMI     SURVIVE
STOP      JSR     CLRPFLGS               ;CLEAR TIMED POWER FLAGS
          LDA     #0                     ;ON DEATH STOP SCROLLING
          STA     SCRATE                 ;THIS GETS A GOOD DEATH ROLLING
          LDA     #1
          STA     BIRDACNT
          LDA     #VHDEATH
          JSR     TUNIN
          LDA     #ALADIN0
          JSR     SCRAPONE               ;KILL BASS LINE OF OPENING TUNE IF

*         ROUTINE (YOU MEAN CODE FRAGMENT) TO DO DEATH ANIMATION
DIE
          DEC     BIRDACNT               ;CHECK ANIMATION DELAY
          BMI     FALLING
          BNE     DIEDONE

          INC     DEATH                  ;ADVANCE DEATH STATE
          LDX     DEATH
          LDA     DEATHDEL-1,X           ;CHECK FOR RESTART
          BEQ     RESTART
          STA     BIRDACNT

          LDA     DEATHANI-1,X           ;POINTER TO GRAPHICS FOR BIRD
          STA     SLTBL+ZBIRD            ;EXPLOSION
          STA     SLTBL+ZSHAD

DIEDONE
          LDA     #$1B
          CLC
          ADC     DEATH
          STA     TEMP8
          JSR     PROJECT
          JMP     SURVIVE

NODEC
          INC     BIRDACNT
          JMP     RESTART1               ;GO TO WAIT FOR END OF TUNES
                                         ;DON'T DEC LIVES AGAIN
FALLING
          LDA     YTBL+ZBIRD
          CMP     #5
          BCC     NODEC

          DEC     YTBL+ZBIRD             ;ONLY DEC IF GREATER THAN 4
          LDX     #$FF                   ;FUCK WITH THE MOVEMENT FLAG
          STX     TEMP7
          INC     BIRDACNT
          LDA     YTBL+ZBIRD
          CMP     #5
          BCS     DIEDONE

* HIT THE GROUND *
          LDA     #CUCKOO1
          JSR     TUNIN
          LDA     #CUCKOO2
          JSR     TUNIN
          LDA     #1
          STA     BIRDACNT
          BNE     DIEDONE                ;ALWAYS BRANCHES

*         TWO PLAYER SWITCH CODE
GMVRTBL   DB      L(BLANKCHR),L(BLANKCHR)
          DB      L(BLANKCHR),L(BLANKCHR),L(BLANKCHR),L(G),L(A),L(M),L(E)
          DB      L(BLANKCHR),L(O),L(V),L(E),L(R),L(BLANKCHR),L(BLANKCHR)
          DB      L(BLANKCHR),L(BLANKCHR),L(BLANKCHR),L(BLANKCHR)

*         CODE TO RESTART AFTER DEATH

RESTART   BIT     AUTOPLAY               ;IN AUTO PLAY, DO IT FAST
          BMI     SAMEPLYR

          LDA     PHASE
          BMI     SAMEPLYR               ;DON'T DO LIVES IF BONUS RACK

          LDX     PLAYER                 ;WHICH PLAYER IS UP
          DEC     PL1LIVES,X             ;DECREMENT LIVES
          BNE     NOTGOVER

          LDA     #42                    ;MOVE HPOS TO ALLOW CENTERING
          STA     DLY+9

          LDY     #19                    ;PUT GAMEPOVER MESSAGE
GMVRLP    LDA     GMVRTBL,Y
          STA     TOPMSMAP,Y
          DEY
          BPL     GMVRLP

          LDA     #ENDGAM1               ;START ENDGAME TUNE
          JSR     TUNIN
          LDA     #ENDGAM0
          JSR     TUNIN
RESTART1  JSR     ZOUNDS
          BNE     WTEOT

NOTGOVER  LDX     PLAYER
          LDA     NUMPLYRS               ;IF TWO PLAYER THEN GOTO TWOPLYR
          CMP     #2
          BEQ     TWOPLYR

          LDA     PL1LIVES,X  ; NO X BFR ;ELSE ONE PLAYER.  SEE IF THERE ARE
          BEQ     GAMEOVER               ;ANY LEFT

          LDA     PHASE
          BNE     LDA0E                  ;NEED TO RESTART IF IN BATTLE
          BEQ     SAMEPLYR               ;OTHERWISE JUST DO PLACEMENT

TWOPLYR   TXA                            ;TRANSFER PLAYER TO ACCUMULATOR
          EOR     #$01                   ;AND TWIDDLE BIT TO GET OTHER PLAYER
          TAY
          LDA     PL1LIVES,Y             ;GET NUMBER OF LIVES FOR OTHER PLAYER
          BEQ     UTTERWAY               ;IF ZERO GOTO UTTERWAY
          STY     PLAYER                 ;ELSE STORE OTHER PLAYER TO PLAYER,CONT
          BNE     LDA0E                  ;FLAG STILL SET FOR LOAD CONTINUE ON??

UTTERWAY  LDA     PL1LIVES,X             ;IF NONE LEFT THEN PUNT
          BEQ     GAMEOVER

SAMEPLYR
          JSR     CLEAN
          JSR     SCRAPALL               ;KILL ALL TUNES
          JSR     PLACEMNT
WTEOT     RTS

LDA0E
          LDA     #$FF
          STA     NEWPLYR
          RTS

*         END GAME CODE
GAMEOVER
          LDX     #$FF
          STX     GAMEOVR
          RTS


*         DOSHOTS  THIS IS THE SHOT ROUTINE
DOSHOTS
          LDA     DEATH                  ;IF DEAD THEN DON'T ALLOW FOR NEW
          BNE     JDONT                  ;SHOTS

          LDA     PHASE
          CMP     #-2
          BEQ     JDONT                  ;CAN'T SHOOT DURING BONUS RACK

          DEC     FIRECNT                ;CHECK FOR FIRING (DELAY)
          BNE     JDONT

          LDA     #1
          STA     FIRECNT

JOHNTMP2  BIT     AUTOPLAY               ;FORCE FIRING IN AUTOPLAY
          BPL     NORMAL

          BIT     FRMCNT
          BMI     SHOTTER                ;SHOT ON NEGATIVE FRAMES
          BPL     JDONT                  ;DON'T ON POSITIVE FRAMES

NORMAL    LDX     PLAYER
          LDA     LEFTBUT,X
          BPL     SHOTTER

JDONT     JMP     DONTFIRE

SHOTTER
          LDX     SHOTCNT                ;COMMENT THIS
          INX
          TXA
          AND     #3
          TAX                            ;SHOT NUMBER
          LDA     SHOTSTAT,X             ;IF SHOT IS STILL AROUND
          BNE     JDONT                  ;THEN DON'T SHOOT

          STX     SHOTCNT

          LDA     #5
          STA     FIRECNT

*         ADJUST X FOR TURNING
          LDA     #8                     ; EAST
          BIT     TEMP0                  ; JOYSTICK VALUE
          BEQ     ADJXEAST
          LDA     #4                     ; WEST
          BIT     TEMP0
          BEQ     ADJXWEST
          LDA     XTBL+ZBIRD
          BNE     ADJXDONE               ; ALWAYS
ADJXEAST  LDA     XTBL+ZBIRD
          CLC
          ADC     #2
          BNE     ADJXDONE               ; ALWAYS
ADJXWEST  LDA     XTBL+ZBIRD
          SEC
          SBC     #2
ADJXDONE  STA     XTBL+ZSHOT1,X          ;SET SHOT COORDINATES (SAME X AS BIRD)
          STA     XTBL+SHOTSHAD,X        ;SHADOW IS SAME, TOO.

*         ADJUST Y FOR GROUND, WATER, OR AIR
          LDA     YTBL+ZBIRD             ;SAME Y AS BIRD
          CMP     #ZYLIMLOW              ;BYTE SAVING POSSIBLE
          BNE     ADJYAIR
          BIT     SWIMMING
          BMI     ADJYH2O                ; IF IN WATER
          LDA     #7
          BNE     ADJYDONE
ADJYH2O   LDA     #3
          BNE     ADJYDONE               ;NEVER HAPPENS.  WHAT DA FUCK??
ADJYAIR   CLC                            ;WHAT GIVES FOLKS??
          ADC     #1
ADJYDONE  STA     YTBL+ZSHOT1,X

          LDA     #ZBIRDZ+6              ;Z IS SAME FOR SHOT AND SHADOW
          STA     ZTBL+ZSHOT1,X
          STA     ZTBL+SHOTSHAD,X

          LDA     #0                     ;Y OF SHADOW IS 0
          STA     YTBL+SHOTSHAD,X

NOHACK    LDA     #$80                   ;SET SHOT STATUS
          STA     SHOTSTAT,X

          LDA     #L(SHOTAN0)            ; INITIAL ANIMATION ADDRESS
          STA     SLTBL+ZSHOT1,X
          STA     SLTBL+SHOTSHAD,X


*         CODE TO DO PROJECTION FOR NEW SHOT.  CALCULATES HP AND VP FROM X,Y,Z
          LDA     XTBL+ZSHOT1,X
          CLC
          ADC     ZTBL+ZSHOT1,X
          ADC     #L(-NUMBER-7)          ;-7 IS HPOFF FOR BOTH SHOT ANIMATIONS
          STA     HPTBL+ZSHOT1,X         ;HERE ARE THE SHOT AND SHADOW HP'S
          STA     HPTBL+SHOTSHAD,X

          LDA     XTBL+ZSHOT1,X
          SEC
          SBC     ZTBL+ZSHOT1,X
          CLC
          ADC     #NUMBER
          STA     VPTBL+SHOTSHAD,X       ;HERE IS SHADOW VP
          SEC
          SBC     YTBL+ZSHOT1,X
          STA     VPTBL+ZSHOT1,X         ;HERE IS SHOT VP

* CALCULATE PRIORITY AND INSERT NEW SHOT IN OBJECT LIST
          LDA     #$FE
          STA     TEMP6                  ;PRIORITY OF SHADOW IS FE
          STA     TEMP10
          STX     TEMPX
          TXA
          CLC
          ADC     #SHOTSHAD              ;INDEX OF SHADOW
          TAX
          JSR     OBJINS                 ;INSERT IT
          LDX     TEMPX

          LDA     ZTBL+ZSHOT1,X          ; Z-X+NUMBER+OFFSET
          SEC
          SBC     XTBL+ZSHOT1,X
          CLC
          ADC     #NUMBER+DXADJ          ; THIS IS DF
          STA     TEMP10
          SEC
          SBC     #5                     ; THIS IS DS
          STA     TEMP6                  ;PRIORITY OF SHOT
          TXA
          CLC
          ADC     #ZSHOT1
          TAX
          JSR     OBJINS                 ; INSERT NEW SHOT IN LIST

          LDA     #BRDSHOT               ; SOUND OF SHOT
          JSR     TUNIN


*         MOVE THE FOUR HERO SHOTS
DONTFIRE
          LDX     #ZSHOT1+4              ; INDEX INTO OBJECT TABLES

NEXTSHOT  DEX                            ;LOOP THROUGH ALL SHOTS
          CPX     #ZSHOT1
          BCS     DOSHOT

* SETBACK IS NOT CALLED ANYMORE
;         JSR     SETBACK                ; MOVE THIS TO MAIN LOOP
          RTS                            ; DONE MOVING SHOTS

DOSHOT    LDA     SHOTSTAT-ZSHOT1,X
          BEQ     NEXTSHOT               ; SHOT X IS INACTIVE

* CODE TO ANIMATE SHOT (EXPLODE)
          BMI     MOVESHOT               ;IF TOP BIT IS CLEAR, IT IS EXPLODING
          DEC     SHOTSTAT-ZSHOT1,X

          LDA     SHOTSTAT-ZSHOT1,X
          BNE     DOSHOTAN
JKILLSHT  JMP     KILLSHOT               ;REMOVE SHOT WHEN IT IS DONE EXPLODING

DOSHOTAN  AND     #$3
          BNE     NEXTSHOT
          LDA     SLTBL,X                ;ADJUST LOW BYTE OF GRAPHICS
          CLC
          ADC     #2                     ; EXPLOSION STAMPS FOLLOW SHOT STAMPS
          STA     SLTBL,X
          STA     SLTBL+SHOTDIFF,X       ;SHADOW TOO!
          JMP     NEXTSHOT

* MOVE SHOT
MOVESHOT
          LDA     ZTBL,X                 ; DO SHOT Z CALCULATION
          CLC
          ADC     QUIKSHOT               ;SHOTS MOVE THREE Z AT A TIME
          STA     ZTBL,X
          STA     ZTBL+SHOTDIFF,X

          STA     COLPZ                  ; FOR COLLISION DETECTION CALLS BELOW

          CMP     #ZBIRDZ+27             ; WAS 25
          BCC     NOBIGGER

          LDA     #L(SHOTAN0+2)          ;THIS CORRECTS SHOT GRAPHICS WHEN THEY
          STA     SLTBL,X                ;SHOULD BE MAX SIZE
          STA     SLTBL+SHOTDIFF,X

NOBIGGER  LDA     HPTBL,X                ;HP CHANGES BY THREE
          CLC
          ADC     QUIKSHOT
          STA     HPTBL,X
          STA     HPTBL+SHOTDIFF,X       ;SHADOW, TOO!

          CMP     #160                   ; OFF RIGHT SIDE OF SCREEN?
BKILLSHT  BCS     JKILLSHT

          LDA     VPTBL,X                ;TAKE AWAY THREE FROM VP
          SEC
          SBC     QUIKSHOT
          STA     VPTBL,X
          CLC
          ADC     YTBL,X
          STA     VPTBL+SHOTDIFF,X

          LDA     VPTBL+SHOTDIFF,X       ;DON'T FORGET THAT PESKY SHADOW
          CMP     #SCRENBOT
          BCC     NOKILLSH
          CMP     #-8

          BCS     BKILLSHT               ;THIS BCS'S TO ANOTHER BCS

NOKILLSH  LDA     DXTBL,X
;         CLC
          ADC     QUIKSHOT
          STA     TEMP6

          LDA     DFTBL,X
          CLC
          ADC     QUIKSHOT
          STA     TEMP10

          JSR     OBJMOV                 ; MOVE SHOT IN LIST


*         DO COLLISION DETECTION FOR SHOT
          LDA     XTBL,X                 ;CHECK X,Y,Z
          STA     COLPX
          LDA     YTBL,X
          STA     COLPY
          STX     TEMP0                  ;X HERE IS SHOT INDEX
          JSR     COLDET                 ;IN THE COLLISION LIST
          BNE     ASHOTT                 ;YES, A COLLISION
          LDX     TEMP0

          LDA     COLPZ
          SEC
          SBC     QUIKSHOT
          STA     COLPZ
          JSR     COLDET
          BNE     ASHOTT
SAVESHOT  LDX     TEMP0

          JMP     NEXTSHOT


*         INITIATE SHOT EXPLOSION ANIMATION
EXPLSHOT
          LDX     TEMP0
          LDA     #RICCHET               ; CALL SOUND OF SHOT RICCOCHET
          JSR     TUNIN
          LDA     #$8                    ; INITIAL EXPLOSION STATE + 1
          STA     SHOTSTAT-ZSHOT1,X
          LDA     #L(SHOTAN0+4)          ;GRAPHICS FOR SPLAT
          STA     SLTBL,X
          STA     SLTBL+SHOTDIFF,X
          JMP     NEXTSHOT               ;LOOP FOR NEXT SHOT


*         DETEMINE WHAT THE SHOT COLLIDED WITH AND ACT APPROPRIATELY
ASHOTT
          CMP     #FLEACOL               ;HOW ABOUT A FLEA?
          BNE     ASHOT1
          JSR     KILLFLEA               ;BLOW FLEAS DOORS OFF
          BIT     TRDSPFLG               ;IF DISPLAY ALREADY UP THEN DON'T
          BMI     EXPLSHOT               ;PUT IT UP AGAIN
          JSR     INITRSMP               ;PUT UP TREASURE DISPLAY
          JMP     EXPLSHOT

ASHOT1    CMP     #UWECOL                ;WHAT ABOUT A UWE
          BNE     ASHOT2
          JSR     KILLUWE
          JMP     EXPLSHOT

ASHOT2    CMP     #MINICOL               ;A MINI SPHINX?
          BNE     ASHOT3
          JSR     MINIKILL
          JMP     EXPLSHOT

ASHOT3    CMP     #SPHNXCOL              ;THE BIG SPHINX?
          BNE     ASHOT4
          JSR     KILLSPHX
          JMP     EXPLSHOT

ASHOT4    CMP     #FIRECOL               ; FIRE??????
          BNE     ASHOT5
          JMP     SAVESHOT               ; DON'T EXPLODE IT

ASHOT5    CMP     #TREASCOL              ; A TREASURE ????
          BCC     ASHOT6                 ; NO
          CMP     #TREASCOL+3
          BCS     ASHOT6                 ; NO
          JSR     HITTREAS               ; YES
          JMP     EXPLSHOT

ASHOT6    JMP     EXPLSHOT

*         CHANGE SHOT TO INACTIVE STATE
KILLSHOT  LDA     #0                     ;RESET SHOTSTAT
          STA     SHOTSTAT-ZSHOT1,X

          JSR     OBJDEL                 ;REMOVE SHOT FROM LIST

          STX     TEMPX
          TXA
          CLC
          ADC     #SHOTDIFF
          TAX
          JSR     OBJDEL                 ;REMOVE SHADOW FROM LIST
          LDX     TEMPX
          JMP     NEXTSHOT
          RTS

*         SIMULATAED GAMEPLAY FROM AUTOPLAY
JOYSIM    DB      $F0,$F0,$F0,$D0,$70,$D0,$E0,$50,$60,$70,$90,$A0,$B0,$D0,$E0
          DB      $F0

; TABLE TO TRANSLATE SWCHA TO ACTION, HIGH NIBBLE FOR NEAR GROUND
;
JOYTBL    DB      $00                   ; N S W E - ILLEGAL
          DB      $00                   ;   S W E - ILLEGAL
          DB      $00                   ; N   W E - ILLEGAL
          DB      $00                   ;     W E - ILLEGAL
          DB      $00                   ; N S   E - ILLEGAL
          DB      $B7                   ;   S   E
          DB      $E5                   ; N     E
          DB      $C3                   ;       E
          DB      $00                   ; N S W   - ILLEGAL
          DB      $B8                   ;   S W
          DB      $F6                   ; N   W
          DB      $D4                   ;     W
          DB      $00                   ; N S     - ILLEGAL
          DB      $B2                   ;   S
          DB      $A1                   ; N
          DB      $90                   ; NONE

; TABLE TO TRANSLATE STATE AND ACTION INTO NEW STATE (HIGH) AND CONTROL CODE
;
STATETBL  DB      $10                   ; F0 A     FLIGHT STATES
          DB      $11                   ; F0 AN
          DB      $12                   ; F0 AS
          DB      $13                   ; F0 AE
          DB      $13                   ; F0 AW
          DB      $14                   ; F0 ANE
          DB      $14                   ; F0 ANW
          DB      $15                   ; F0 ASE
          DB      $15                   ; F0 ASW
          DB      $16                   ; F0 G
          DB      $16                   ; F0 GN
          DB      $12                   ; F0 GS,GSE,GSW
          DB      $16                   ; F0 GE
          DB      $16                   ; F0 GW
          DB      $16                   ; F0 GNE
          DB      $16                   ; F0 GNW
          DB      $20                   ; F1 A
          DB      $11                   ; F1 AN
          DB      $22                   ; F1 AS
          DB      $23                   ; F1 AE
          DB      $23                   ; F1 AW
          DB      $14                   ; F1 ANE
          DB      $14                   ; F1 ANW
          DB      $25                   ; F1 ASE
          DB      $25                   ; F1 ASW
          DB      $26                   ; F1 G
          DB      $47                   ; F1 GN
          DB      $22                   ; F1 GS,GSE,GSW
          DB      $26                   ; F1 GE
          DB      $26                   ; F1 GW
          DB      $47                   ; F1 GNE
          DB      $47                   ; F1 GNW
          DB      $30                   ; F2 A
          DB      $31                   ; F2 AN
          DB      $32                   ; F2 AS
          DB      $33                   ; F2 AE
          DB      $33                   ; F2 AW
          DB      $34                   ; F2 ANE
          DB      $34                   ; F2 ANW
          DB      $35                   ; F2 ASE
          DB      $35                   ; F2 ASW
          DB      $36                   ; F2 G
          DB      $36                   ; F2 GN
          DB      $32                   ; F2 GS,GSE,GSW
          DB      $36                   ; F2 GE
          DB      $36                   ; F2 GW
          DB      $36                   ; F2 GNE
          DB      $36                   ; F2 GNW
          DB      $00                   ; F3 A
          DB      $01                   ; F3 AN
          DB      $02                   ; F3 AS
          DB      $03                   ; F3 AE
          DB      $03                   ; F3 AW
          DB      $04                   ; F3 ANE
          DB      $04                   ; F3 ANW
          DB      $05                   ; F3 ASE
          DB      $05                   ; F3 ASW
          DB      $06                   ; F3 G
          DB      $06                   ; F3 GN
          DB      $02                   ; F3 GS,GSE,GSW
          DB      $06                   ; F3 GE
          DB      $06                   ; F3 GW
          DB      $06                   ; F3 GNE
          DB      $06                   ; F3 GNW
          DB      $58                   ; S0 A     STALL STATES
          DB      $58                   ; S0 AN
          DB      $3F                   ; S0 AS
          DB      $58                   ; S0 AE
          DB      $58                   ; S0 AW
          DB      $58                   ; S0 ANE
          DB      $58                   ; S0 ANW
          DB      $3F                   ; S0 ASE
          DB      $3F                   ; S0 ASW
          DB      $58                   ; S0 G
          DB      $58                   ; S0 GN
          DB      $3F                   ; S0 GS,GSE,GSW
          DB      $58                   ; S0 GE
          DB      $58                   ; S0 GW
          DB      $58                   ; S0 GNE
          DB      $58                   ; S0 GNW
          DB      $49                   ; S1 A
          DB      $69                   ; S1 AN
          DB      $49                   ; S1 AS
          DB      $49                   ; S1 AE
          DB      $49                   ; S1 AW
          DB      $69                   ; S1 ANE
          DB      $69                   ; S1 ANW
          DB      $49                   ; S1 ASE
          DB      $49                   ; S1 ASW
          DB      $49                   ; S1 G
          DB      $69                   ; S1 GN
          DB      $49                   ; S1 GS,GSE,GSW
          DB      $49                   ; S1 GE
          DB      $49                   ; S1 GW
          DB      $69                   ; S1 GNE
          DB      $69                   ; S1 GNW
          DB      $7B                   ; L0 A     LANDING STATES
          DB      $7B                   ; L0 AN
          DB      $CF                   ; L0 AS
          DB      $7B                   ; L0 AE
          DB      $7B                   ; L0 AW
          DB      $7B                   ; L0 ANE
          DB      $7B                   ; L0 ANW
          DB      $CF                   ; L0 ASE
          DB      $CF                   ; L0 ASW
          DB      $7B                   ; L0 G
          DB      $7B                   ; L0 GN
          DB      $CF                   ; L0 GS,GSE,GSW
          DB      $7B                   ; L0 GE
          DB      $7B                   ; L0 GW
          DB      $7B                   ; L0 GNE
          DB      $7B                   ; L0 GNW
          DB      $8C                   ; L1 A
          DB      $8C                   ; L1 AN
          DB      $BF                   ; L1 AS
          DB      $8C                   ; L1 AE
          DB      $8C                   ; L1 AW
          DB      $8C                   ; L1 ANE
          DB      $8C                   ; L1 ANW
          DB      $BF                   ; L1 ASE
          DB      $BF                   ; L1 ASW
          DB      $8C                   ; L1 G
          DB      $8C                   ; L1 GN
          DB      $BF                   ; L1 GS,GSE,GSW
          DB      $8C                   ; L1 GE
          DB      $8C                   ; L1 GW
          DB      $8C                   ; L1 GNE
          DB      $8C                   ; L1 GNW
          DB      $8D                   ; H0 A     HOPPING STATES
          DB      $8E                   ; H0 AN
          DB      $AF                   ; H0 AS
          DB      $8E                   ; H0 AE
          DB      $8E                   ; H0 AW
          DB      $8E                   ; H0 ANE
          DB      $8E                   ; H0 ANW
          DB      $AF                   ; H0 ASE
          DB      $AF                   ; H0 ASW
          DB      $8D                   ; H0 G
          DB      $9D                   ; H0 GN
          DB      $9D                   ; H0 GS,GSE,GSW
          DB      $9D                   ; H0 GE
          DB      $9D                   ; H0 GW
          DB      $9D                   ; H0 GNE
          DB      $9D                   ; H0 GNW
          DB      $8D                   ; H1 A
          DB      $8E                   ; H1 AN
          DB      $8E                   ; H1 AS
          DB      $8E                   ; H1 AE
          DB      $8E                   ; H1 AW
          DB      $8E                   ; H1 ANE
          DB      $8E                   ; H1 ANW
          DB      $8E                   ; H1 ASE
          DB      $8E                   ; H1 ASW
          DB      $8E                   ; H1 G
          DB      $8E                   ; H1 GN
          DB      $AF                   ; H1 GS,GSE,GSW  WAS 8E
          DB      $8E                   ; H1 GE
          DB      $8E                   ; H1 GW
          DB      $8E                   ; H1 GNE
          DB      $8E                   ; H1 GNW
          DB      $8F                   ; T0 A     TAKE-OFF STATES
          DB      $8F                   ; T0 AN
          DB      $BC                   ; T0 AS
          DB      $8F                   ; T0 AE
          DB      $8F                   ; T0 AW
          DB      $8F                   ; T0 ANE
          DB      $8F                   ; T0 ANW
          DB      $BC                   ; T0 ASE
          DB      $BC                   ; T0 ASW
          DB      $8F                   ; T0 G
          DB      $8F                   ; T0 GN
          DB      $BC                   ; T0 GS,GSE,GSW
          DB      $8F                   ; T0 GE
          DB      $8F                   ; T0 GW
          DB      $8F                   ; T0 GNE
          DB      $8F                   ; T0 GNW
          DB      $7F                   ; T1 A
          DB      $7F                   ; T1 AN
          DB      $CB                   ; T1 AS
          DB      $7F                   ; T1 AE
          DB      $7F                   ; T1 AW
          DB      $7F                   ; T1 ANE
          DB      $7F                   ; T1 ANW
          DB      $CB                   ; T1 ASE
          DB      $CB                   ; T1 ASW
          DB      $7F                   ; T1 G
          DB      $7F                   ; T1 GN
          DB      $CB                   ; T1 GS,GSE,GSW
          DB      $7F                   ; T1 GE
          DB      $7F                   ; T1 GW
          DB      $7F                   ; T1 GNE
          DB      $7F                   ; T1 GNW
          DB      $4F                   ; T2 A
          DB      $6F                   ; T2 AN
          DB      $2A                   ; T2 AS
          DB      $4F                   ; T2 AE
          DB      $4F                   ; T2 AW
          DB      $6F                   ; T2 ANE
          DB      $6F                   ; T2 ANW
          DB      $2A                   ; T2 ASE
          DB      $2A                   ; T2 ASW
          DB      $4F                   ; T2 G
          DB      $6F                   ; T2 GN
          DB      $2A                   ; T2 GS,GSE,GSW
          DB      $4F                   ; T2 GE
          DB      $4F                   ; T2 GW
          DB      $6F                   ; T2 GNE
          DB      $6F                   ; T2 GNW

; TABLE TO TRANSLATE STATE AND ACTION TO ANIMATION NUMBER
;
BIRDATBL  DB      $80                    ;F0
          DB      $90                    ;F1
          DB      $80                    ;F2
          DB      $A0                    ;F3
          DB      $A                     ;S0
          DB      $9                     ;S1
          DB      $B                     ;L0
          DB      $C                     ;L1
          DB      $B0                    ;H0
          DB      $C0                    ;H1
          DB      $13                    ;T0
          DB      $14                    ;T1
          DB      $15                    ;T2

BIRDAI    DB      $0                     ; F0 A
          DB      $0                     ; F0 AN
          DB      $0                     ; F0 AS
          DB      $3                     ; F0 AE
          DB      $6                     ; F0 AW
          DB      $3                     ; F0 ANE
          DB      $6                     ; F0 ANW
          DB      $3                     ; F0 ASE
          DB      $6                     ; F0 ASW
          DB      $0                    ; F0 G
          DB      $0                    ; F0 GN
          DB      $0                    ; F0 GS,GSE,GSW
          DB      $3                    ; F0 GE
          DB      $6                    ; F0 GW
          DB      $3                    ; F0 GNE
          DB      $6                    ; F0 GNW
          DB      $1                     ; F1 A
          DB      $1                     ; F1 AN
          DB      $1                     ; F1 AS
          DB      $4                     ; F1 AE
          DB      $7                     ; F1 AW
          DB      $4                     ; F1 ANE
          DB      $7                     ; F1 ANW
          DB      $4                     ; F1 ASE
          DB      $7                     ; F1 ASW
          DB      $1                    ; F1 G
          DB      $1                    ; F1 GN
          DB      $1                    ; F1 GS,GSE,GSW
          DB      $4                    ; F1 GE
          DB      $7                    ; F1 GW
          DB      $4                    ; F1 GNE
          DB      $7                    ; F1 GNW
          DB      $2                     ; F3 A
          DB      $2                     ; F3 AN
          DB      $2                     ; F3 AS
          DB      $5                     ; F3 AE
          DB      $8                     ; F3 AW
          DB      $5                     ; F3 ANE
          DB      $8                     ; F3 ANW
          DB      $5                     ; F3 ASE
          DB      $8                     ; F3 ASW
          DB      $2                    ; F3 G
          DB      $2                    ; F3 GN
          DB      $2                    ; F3 GS,GSE,GSW
          DB      $5                    ; F3 GE
          DB      $8                    ; F3 GW
          DB      $5                    ; F3 GNE
          DB      $8                    ; F3 GNW
          DB      $96                   ; H0 A
          DB      $97                   ; H0 AN
          DB      $96                   ; H0 AS
          DB      $98                   ; H0 AE
          DB      $99                   ; H0 AW
          DB      $9A                   ; H0 ANE
          DB      $9B                   ; H0 ANW
          DB      $96                   ; H0 ASE
          DB      $96                   ; H0 ASW
          DB      $E                    ; H0 G
          DB      $E                    ; H0 GN
          DB      $E                    ; H0 GS,GSE,GSW
          DB      $10                   ; H0 GE
          DB      $12                   ; H0 GW
          DB      $10                   ; H0 GNE
          DB      $12                   ; H0 GNW
          DB      $D                    ; H1 A
          DB      $D                    ; H1 AN
          DB      $D                    ; H1 AS
          DB      $F                    ; H1 AE
          DB      $11                   ; H1 AW
          DB      $F                    ; H1 ANE
          DB      $11                   ; H1 ANW
          DB      $D                    ; H1 ASE
          DB      $D                    ; H1 ASW
          DB      $D                    ; H1 G
          DB      $D                    ; H1 GN
          DB      $D                    ; H1 GS,GSE,GSW
          DB      $F                    ; H1 GE
          DB      $11                   ; H1 GW
          DB      $F                    ; H1 GNE
          DB      $11                   ; H1 GNW

; TABLE TO TRANSLATE CONTROL CODE INTO SCROLLING RATE
;
SCRATBL   DB      -1                     ; NORMAL FLIGHT
          DB      -1                     ; DIVING
          DB      -1                     ; CLIMBING
          DB      -1                     ; TURNING
          DB      -1                     ; DIVING + TURNING
          DB      -1                     ; CLIMBING + TURNING
          DB      2                      ; LAST FLAP     THESE ARE ABSOLUTE
          DB      2                      ; LAST GLIDE
          DB      1                      ; STALL 0
          DB      1                      ; STALL 1
          DB      1                      ; H = 3
          DB      1                      ; H = 2
          DB      1                      ; H = 1
          DB      0                      ; STAND
          DB      2                      ; HOP
          DB      0                      ; STAY          NO CHANGE

; TABLE TO TRANSLATE CONTROL CODE INTO ANIMATION DELAY
;
ADELTBL   DB      3                      ; NORMAL FLIGHT
          DB      2                      ; DIVING
          DB      2                      ; CLIMBING
          DB      3                      ; TURNING
          DB      2                      ; DIVING + TURNING
          DB      2                      ; CLIMBING + TURNING
          DB      4                      ; LAST FLAP
          DB      2                      ; LAST GLIDE
          DB      3                      ; STALL 0
          DB      3                      ; STALL 1
          DB      2                      ; H = 3
          DB      2                      ; H = 2
          DB      3                      ; H = 1
          DB      2                      ; STAND
          DB      2                      ; HOP
          DB      2                      ; STAY       WAS 1

; TABLE TO TRANSLATE CONTROL CODE INTO X UPDATE DELAY
;
XDELTBL   DB      0                      ; NORMAL FLIGHT
          DB      0                      ; DIVING
          DB      0                      ; CLIMBING
          DB      1                      ; TURNING
          DB      1                      ; DIVING + TURNING
          DB      1                      ; CLIMBING + TURNING
          DB      1                      ; LAST FLAP
          DB      1                      ; LAST GLIDE
          DB      2                      ; STALL 0
          DB      2                      ; STALL 1
          DB      0                      ; H = 3
          DB      0                      ; H = 2
          DB      0                      ; H = 1
          DB      2                      ; STAND
          DB      2                      ; HOP
          DB      2                      ; STAY

; TABLE TO TRANSLATE CONTROL CODE INTO Y UPDATE MODES

;         0       DON'T UPDATE Y
;         -1      INCREMENT OR DECREMENT Y DEPENDING ON JOYSTICK
;         N > 0   SET Y TO N
YMODTBL   DB      0                      ; NORMAL FLIGHT
          DB      -1                     ; DIVING
          DB      -1                     ; CLIMBING
          DB      0                      ; TURNING
          DB      -1                     ; DIVING + TURNING
          DB      -1                     ; CLIMBING + TURNING
          DB      ZYLIMLOW+4             ; LAST FLAP
          DB      ZYLIMLOW+4             ; LAST GLIDE
          DB      ZYLIMLOW+3             ; STALL 0
          DB      ZYLIMLOW+3             ; STALL 1
          DB      ZYLIMLOW+6             ; H = 6
          DB      ZYLIMLOW+3             ; H = 3
          DB      ZYLIMLOW+1             ; H = 1
          DB      ZYLIMLOW               ; STAND
          DB      ZYLIMLOW               ; HOP
          DB      0                      ; STAY

; TABLE TO TRANSLATE ANIMATION NUMBER TO BIRD ANIMATION ADDRESS
;
BIRDANAD  DB      L(BIRDFMS)             ; 0
          DB      L(BIRDFUS)             ; 1
          DB      L(BIRDFDS)             ; 2
          DB      L(BIRDFMR)             ; 3
          DB      L(BIRDFUR)             ; 4
          DB      L(BIRDFDR)             ; 5
          DB      L(BIRDFML)             ; 6
          DB      L(BIRDFUL)             ; 7
          DB      L(BIRDFDL)             ; 8
          DB      L(BIRDSU)              ; 9
          DB      L(BIRDSD)              ; A
          DB      L(BIRDLU)              ; B
          DB      L(BIRDLD)              ; C
          DB      L(BIRDHUS)             ; D
          DB      L(BIRDHDS)             ; E
          DB      L(BIRDHUR)             ; F
          DB      L(BIRDHDR)             ; 10
          DB      L(BIRDHUL)             ; 11
          DB      L(BIRDHDL)             ; 12
          DB      L(BIRDTU1)             ; 13
          DB      L(BIRDTD)              ; 14
          DB      L(BIRDTU2)             ; 15
          DB      L(BIRDWS)             ; 16
          DB      L(BIRDWS)             ; 17
          DB      L(BIRDWR)             ; 18
          DB      L(BIRDWL)             ; 19
          DB      L(BIRDWR)             ; 1A
          DB      L(BIRDWL)             ; 1B

; TABLE TO TRANSLATE ANIMATION NUMBER TO SHADOW ANIMATION ADDRESS
;
SHADANAD  DB      L(BIRDFMS)             ; 0
          DB      L(BIRDFUS)             ; 1
          DB      L(BIRDFDS)             ; 2
          DB      L(BIRDFMR)             ; 3
          DB      L(BIRDFUR)             ; 4
          DB      L(BIRDFDR)             ; 5
          DB      L(BIRDFML)             ; 6
          DB      L(BIRDFUL)             ; 7
          DB      L(BIRDFDL)             ; 8
          DB      L(SHADSU)              ; 9
          DB      L(SHADSD)              ; A
          DB      L(BIRDLU)              ; B
          DB      L(BIRDLD)              ; C
          DB      L(SHADHUS)              ; D
          DB      L(SHADHDS)              ; E
          DB      L(SHADHUR)              ; F
          DB      L(SHADHDR)              ; 10
          DB      L(SHADHUL)              ; 11
          DB      L(SHADHDL)              ; 12
          DB      L(BIRDTU1)             ; 13
          DB      L(BIRDTD)              ; 14
          DB      L(BIRDTU2)             ; 15
          DB      L(UWEBLANK)            ; 16
          DB      L(UWEBLANK)            ; 17
          DB      L(UWEBLANK)            ; 18
          DB      L(UWEBLANK)            ; 19
          DB      L(UWEBLANK)            ; 1A
          DB      L(UWEBLANK)            ; 1B

DOFF1     EQU     0
DOFF2     EQU     2
DOFF3     EQU     5
DOFF4     EQU     7
DOFF5     EQU     8
DOFF6     EQU     8

; TABLE TO TRANSLATE ANIMATION NUMBER TO BIRD HORIZONAL POSITION OFFSET
;         - NUMBER + OFFSET
BHPOFF    DB      L(-NUMBER-7)              ; 0
          DB      L(-NUMBER-7)              ; 1
          DB      L(-NUMBER-7)              ; 2
          DB      L(-NUMBER-7)              ; 3
          DB      L(-NUMBER-7)              ; 4
          DB      L(-NUMBER-7)              ; 5
          DB      L(-NUMBER-7)              ; 6
          DB      L(-NUMBER-7)              ; 7
          DB      L(-NUMBER-7)              ; 8
          DB      L(-NUMBER-7)              ; 9
          DB      L(-NUMBER-7)              ; A
          DB      L(-NUMBER-8)              ; B
          DB      L(-NUMBER-7)              ; C
          DB      L(-NUMBER-7)              ; D
          DB      L(-NUMBER-7)              ; E
          DB      L(-NUMBER-6)              ; F
          DB      L(-NUMBER-6)              ; 10
          DB      L(-NUMBER-7)              ; 11
          DB      L(-NUMBER-7)              ; 12
          DB      L(-NUMBER-7)              ; 13
          DB      L(-NUMBER-7)              ; 14
          DB      L(-NUMBER-7)              ; 15
          DB      L(-NUMBER-7)              ; 16
          DB      L(-NUMBER-7)              ; 17
          DB      L(-NUMBER-7)              ; 18
          DB      L(-NUMBER-7)              ; 19
          DB      L(-NUMBER-7)              ; 1A
          DB      L(-NUMBER-7)              ; 1B
          DB      L(-NUMBER-7-DOFF1)     ;D1
          DB      L(-NUMBER-7-DOFF2)     ;D2
          DB      L(-NUMBER-7-DOFF3)     ;D3
          DB      L(-NUMBER-7-DOFF4)     ;D4
          DB      L(-NUMBER-7-DOFF5)     ;D5
          DB      L(-NUMBER-7-DOFF6)     ;D6
          DB      L(-NUMBER-7-DOFF5)     ;D5
          DB      L(-NUMBER-7-DOFF6)     ;D6
          DB      L(-NUMBER-7-DOFF5)     ;D5
          DB      L(-NUMBER-7-DOFF6)     ;D6

; TABLE TO TRANSLATE ANIMATION NUMBER TO BIRD VERTICAL POSITION OFFSET
;         NUMBER + OFFSET
BVPOFF    DB      NUMBER-7               ; 0
          DB      NUMBER-7               ; 1
          DB      NUMBER-7               ; 2
          DB      NUMBER-8               ; 3
          DB      NUMBER-8               ; 4
          DB      NUMBER-6               ; 5
          DB      NUMBER-4               ; 6
          DB      NUMBER-4               ; 7
          DB      NUMBER-5               ; 8
          DB      NUMBER-8               ; 9
          DB      NUMBER-8               ; A
          DB      NUMBER-4               ; B
          DB      NUMBER-4               ; C
          DB      NUMBER-7               ; D
          DB      NUMBER-7               ; E
          DB      NUMBER-9               ; F
          DB      NUMBER-7               ; 10 WAS -8
          DB      NUMBER-9               ; 11
          DB      NUMBER-8               ; 12
          DB      NUMBER-9               ; 13
          DB      NUMBER-6               ; 14
          DB      NUMBER-7               ; 15
          DB      NUMBER-4               ; 16
          DB      NUMBER-4               ; 17
          DB      NUMBER-7               ; 18
          DB      NUMBER-7               ; 19
          DB      NUMBER-7               ; 1A
          DB      NUMBER-7               ; 1B
          DB      NUMBER-7+DOFF1         ; D1
          DB      NUMBER-7+DOFF2         ; D2
          DB      NUMBER-7+DOFF3         ; D3
          DB      NUMBER-7+DOFF4         ; D4
          DB      NUMBER-7+DOFF5         ; D5
          DB      NUMBER-7+DOFF6         ; D6
          DB      NUMBER-7+DOFF5         ; D5
          DB      NUMBER-7+DOFF6         ; D6
          DB      NUMBER-7+DOFF5         ; D5
          DB      NUMBER-7+DOFF6         ; D6

; TABLE TO TRANSLATE ANIMATION NUMBER TO SHADOW VERTICAL POSITION OFFSET
;         NUMBER + OFFSET
SVPOFF    DB      NUMBER-7               ; 0
          DB      NUMBER-8               ; 1
          DB      NUMBER-5               ; 2
          DB      NUMBER-8               ; 3
          DB      NUMBER-9               ; 4
          DB      NUMBER-5               ; 5
          DB      NUMBER-4               ; 6
          DB      NUMBER-5               ; 7
          DB      NUMBER-4               ; 8
          DB      NUMBER-10              ; 9
          DB      NUMBER-10              ; A
          DB      NUMBER-7               ; B
          DB      NUMBER-7               ; C
          DB      NUMBER-11              ; D
          DB      NUMBER-11              ; E
          DB      NUMBER-12              ; F
          DB      NUMBER-12              ; 10
          DB      NUMBER-11              ; 11
          DB      NUMBER-11              ; 12
          DB      NUMBER-8               ; 13
          DB      NUMBER-5               ; 14
          DB      NUMBER-8               ; 15
          DB      NUMBER-11              ; 16
          DB      NUMBER-11              ; 17
          DB      NUMBER-11              ; 18
          DB      NUMBER-11              ; 19
          DB      NUMBER-11              ; 1A
          DB      NUMBER-11              ; 1B
          DB      NUMBER-11+DOFF1        ;D1
          DB      NUMBER-11+DOFF2        ; D2
          DB      NUMBER-11+DOFF3        ; D3
          DB      NUMBER-11+DOFF4        ; D4
          DB      NUMBER-11+DOFF5        ; D5
          DB      NUMBER-11+DOFF6        ; D6
          DB      NUMBER-11+DOFF5        ; D5
          DB      NUMBER-11+DOFF6        ; D6
          DB      NUMBER-11+DOFF5        ; D5
          DB      NUMBER-11+DOFF6        ; D6

; TABLE OF DEATH ANIMATION ADDRESSES
;
DEATHANI  DB      L(BDS1)
          DB      L(BDS2)
          DB      L(BDS3)
          DB      L(BDS4)
          DB      L(BDS5)
          DB      L(BDS6)
          DB      L(BDS5)
          DB      L(BDS6)
          DB      L(BDS5)
          DB      L(BDS6)
          DB      0

; TABLE OF DEATH ANIMATION DELAYS
;
DEATHDEL  DB      3
          DB      4
          DB      5
          DB      $FF
          DB      6
          DB      6
          DB      6
          DB      6
          DB      6
          DB      6
          DB      0

BIRDROOM  EQU     3

RESETXLO  LDA     #$48
          STA     TEMP4                  ;AND I HOPE I CAN USE TEMP4
          BNE     NORESTX

* WE NEED TO DEAL WITH THIS NOT BEING ABLE TO FIND A PLACE
PLACEMNT
          LDA     #6
          STA     TEMP0                  ;HOPEFULLY I CAN USE TEMP0

          LDA     #ZYLIMLOW              ;THE BIRD WILL BE ON THE GROUND
          STA     YTBL+ZBIRD
          LDA     #$E
          STA     TEMP8                  ; ANIMATION NUMBER FOR PROJECT
          STA     TEMP7                  ; MOVEMENT FLAG

TRYPLAC
          DEC     TEMP0
          BEQ     RESETXLO
          BPL     USERAND

NORESTX   LDA     TEMP4
          CLC
          ADC     #2
          STA     TEMP4
          CMP     #ZXLIMHI
          BCC     FLOWINX
          LDA     #ZXLIMLOW              ;IF OVER, TRY LOWEND
          STA     TEMP4
          BNE     FLOWINX

USERAND   JSR     RANDOM                 ;TRY TO PLACE THE BIRD SAFELY
          LSR     A
          LSR     A
          ADC     #ZXLIMLOW
          CMP     #ZXLIMHI               ;MAKE SURE IT IS IN X RANGE
          BCS     TRYPLAC

FLOWINX   CLC
          ADC     #BIRDROOM
          STA     XTBL+ZBIRD
          LDA     #ZBIRDZ+8
          STA     ZTBL+ZBIRD
          JSR     PROJECT                ; X+3,Z+8
          JSR     DOCOL
          BNE     TRYPLAC

          LDA     #ZBIRDZ
          STA     ZTBL+ZBIRD
          JSR     PROJECT                ; X+3,Z
          JSR     DOCOL
          BNE     TRYPLAC

          LDA     XTBL+ZBIRD
          SEC
          SBC     #BIRDROOM*2
          STA     XTBL+ZBIRD
          JSR     PROJECT                ; X-3,Z
          JSR     DOCOL
          BNE     TRYPLAC

          LDA     #ZBIRDZ+8
          STA     ZTBL+ZBIRD
          JSR     PROJECT                ; X-3,Z+8
          JSR     DOCOL
          BNE     TRYPLAC

          LDA     XTBL+ZBIRD
          CLC
          ADC     #BIRDROOM
          STA     XTBL+ZBIRD
          JSR     PROJECT                ; X,Z+8
          JSR     DOCOL
BTRYPLC   BNE     TRYPLAC

          LDA     #ZBIRDZ
          STA     ZTBL+ZBIRD
          JSR     PROJECT                ; X,Z    - THIS IS WHERE IT STAYS
          JSR     DOCOL
          BNE     BTRYPLC

          LDA     #0                     ;PLACE BIRD BECAUSE WE MADE IT
          STA     DEATH                  ;RESET DEATH STATE

          LDA     #L(BIRDHDS)            ;GRAPHICS OF STANDING BIRD
          STA     SLTBL+ZBIRD
          STA     SLTBL+ZSHAD

          LDA     #$80                   ; HOP MODE
          STA     BIRDSTAT

          LDA     #$FF                   ;JOYSTICK VALUE (NO MOTION)
          STA     TEMP0

PUNTSHIT

          RTS

*         DOCOL   SUBROUTINE TO DO COLLISION DETECTION FOR BIRD
* LEAVES RESULT IN ACCUMULATOR
* MORE WORK SHOULD BE DONE ON DECIDING WHICH POINTS TO USE
DOCOL     LDA     XTBL+ZBIRD             ;STORE X,Y,AND Z FOR FIRST CALL
          STA     COLPX
          LDA     YTBL+ZBIRD
          STA     COLPY
          LDA     ZTBL+ZBIRD
          CLC
          ADC     #2
          STA     COLPZ
          LDX     #ZBIRD
          JSR     COLDTNC
          BNE     COLDONE                ;Z FLAG SHOULD BE SET

* SHOULD CHECK NARROWER IF ON GROUND OR WATER
          LDA     XTBL+ZBIRD             ;TRY X+3,Y,Z-2
          CLC
          ADC     #3
          STA     COLPX
          LDA     ZTBL+ZBIRD
          SEC
          SBC     #2
          STA     COLPZ
          LDX     #ZBIRD
          JSR     COLDTNC                ;SECOND CALL
          BNE     COLDONE                ;Z FLAG SHOULD BE SET

          LDA     XTBL+ZBIRD             ;TRY X-3,Y,Z-2
          SEC
          SBC     #3
          STA     COLPX
          LDX     #ZBIRD
          JSR     COLDTNC                ;THIRD CALL
COLDONE   RTS

PROJECT   LDY     TEMP8                  ; ANIMATION NUMBER FOR OFFSETS

          LDA     XTBL+ZBIRD             ; CALCULATE BIRD AND SHADOW HP
          CLC
          ADC     ZTBL+ZBIRD
          ADC     BHPOFF,Y               ; HPOFF-NUMBER
          STA     HPTBL+ZBIRD            ; HP OF BIRD AND SHADOW
          STA     HPTBL+ZSHAD

          LDA     XTBL+ZBIRD             ; CALCULATE SHADOW VP
          CLC
          ADC     SVPOFF,Y               ; VPOFF+NUMBER
          SEC
          SBC     ZTBL+ZBIRD
          STA     VPTBL+ZSHAD            ; VP OF SHADOW

          LDA     XTBL+ZBIRD             ; CALCULATE BIRD VP
          SEC
          SBC     YTBL+ZBIRD
          CLC
          ADC     BVPOFF,Y               ; VPOFF+NUMBER
          SEC
          SBC     ZTBL+ZBIRD
          STA     VPTBL+ZBIRD            ; VP OF BIRD

          LDA     TEMP7                  ;DON'T DO OBJMOV IF IT DIDN'T
          BEQ     ONLYCOL

WEMOVED   LDA     #NUMBER-7+DXADJ        ; NUMBER+OFFSET
          SEC
          SBC     XTBL+ZBIRD
          CLC
          ADC     ZTBL+ZBIRD             ; THIS IS DC
          STA     TEMP6
          ADC     #14                    ; THIS IS DF
          STA     TEMP10
          LDX     #ZBIRD
          JSR     OBJMOV
ONLYCOL
          RTS

ZOUNDS    LDA     TUNNUM
          CMP     #$FF
          BNE     NOZOUND
          LDA     TUNNUM+1
          CMP     #$FF
                                         ;SET Z FLAG
NOZOUND   RTS

          END

